# coding: utf-8

"""
    Yahoo!広告 検索広告 API リファレンス / Yahoo! JAPAN Ads Search Ads API Reference

    <div lang=\"ja\">Yahoo!広告 検索広告 APIのWebサービスについて説明します。</div> <div lang=\"en\">Search Ads API Web Services supported in Yahoo! JAPAN Ads API.</div> <div><a target=\"_blank\" href=\"https://github.com/yahoojp-marketing/ads-search-api-documents/blob/master/design/v12/Route.yaml\">OpenAPI Specification</a></div> <div lang=\"ja\"><a target=\"_blank\" href=\"https://github.com/yahoojp-marketing/ads-search-api-documents/blob/master/bestpractice/ja\">Best Practice</a></div> <div lang=\"en\"><a target=\"_blank\" href=\"https://github.com/yahoojp-marketing/ads-search-api-documents/blob/master/bestpractice/en\">Best Practice</a></div>   # noqa: E501

    The version of the OpenAPI document: v12
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from yahoo_search_api_v12.configuration import Configuration


class AdGroupCriterionServiceBiddableAdGroupCriterion(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'smartphone_final_url': 'str',
        'final_url': 'str',
        'approval_status': 'AdGroupCriterionServiceApprovalStatus',
        'bid': 'AdGroupCriterionServiceBid',
        'custom_parameters': 'AdGroupCriterionServiceCustomParameters',
        'destination_url': 'str',
        'disapproval_reason_codes': 'list[str]',
        'review_smartphone_final_url': 'str',
        'review_final_url': 'str',
        'review_custom_parameters': 'AdGroupCriterionServiceCustomParameters',
        'review_destination_url': 'str',
        'review_tracking_url': 'str',
        'tracking_url': 'str',
        'user_status': 'AdGroupCriterionServiceUserStatus'
    }

    attribute_map = {
        'smartphone_final_url': 'smartphoneFinalUrl',
        'final_url': 'finalUrl',
        'approval_status': 'approvalStatus',
        'bid': 'bid',
        'custom_parameters': 'customParameters',
        'destination_url': 'destinationUrl',
        'disapproval_reason_codes': 'disapprovalReasonCodes',
        'review_smartphone_final_url': 'reviewSmartphoneFinalUrl',
        'review_final_url': 'reviewFinalUrl',
        'review_custom_parameters': 'reviewCustomParameters',
        'review_destination_url': 'reviewDestinationUrl',
        'review_tracking_url': 'reviewTrackingUrl',
        'tracking_url': 'trackingUrl',
        'user_status': 'userStatus'
    }

    def __init__(self, smartphone_final_url=None, final_url=None, approval_status=None, bid=None, custom_parameters=None, destination_url=None, disapproval_reason_codes=None, review_smartphone_final_url=None, review_final_url=None, review_custom_parameters=None, review_destination_url=None, review_tracking_url=None, tracking_url=None, user_status=None, local_vars_configuration=None):  # noqa: E501
        """AdGroupCriterionServiceBiddableAdGroupCriterion - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._smartphone_final_url = None
        self._final_url = None
        self._approval_status = None
        self._bid = None
        self._custom_parameters = None
        self._destination_url = None
        self._disapproval_reason_codes = None
        self._review_smartphone_final_url = None
        self._review_final_url = None
        self._review_custom_parameters = None
        self._review_destination_url = None
        self._review_tracking_url = None
        self._tracking_url = None
        self._user_status = None
        self.discriminator = None

        self.smartphone_final_url = smartphone_final_url
        self.final_url = final_url
        self.approval_status = approval_status
        self.bid = bid
        self.custom_parameters = custom_parameters
        self.destination_url = destination_url
        self.disapproval_reason_codes = disapproval_reason_codes
        self.review_smartphone_final_url = review_smartphone_final_url
        self.review_final_url = review_final_url
        self.review_custom_parameters = review_custom_parameters
        self.review_destination_url = review_destination_url
        self.review_tracking_url = review_tracking_url
        self.tracking_url = tracking_url
        self.user_status = user_status

    @property
    def smartphone_final_url(self):
        """Gets the smartphone_final_url of this AdGroupCriterionServiceBiddableAdGroupCriterion.  # noqa: E501

        <div lang=\"ja\">最終リンク先URL（スマートフォン）です。<br> ADDおよびSET時、このフィールドは省略可能となります。<br> ※空で設定すると、既存の最終リンク先URL（スマートフォン）は削除されます。</div> <div lang=\"en\">Upgraded final URL (Smartphone).<br> This field is optional in ADD and SET operation.<br> *When tag is set blank, existing upgraded Final URL (Smartphone) will be deleted.</div>   # noqa: E501

        :return: The smartphone_final_url of this AdGroupCriterionServiceBiddableAdGroupCriterion.  # noqa: E501
        :rtype: str
        """
        return self._smartphone_final_url

    @smartphone_final_url.setter
    def smartphone_final_url(self, smartphone_final_url):
        """Sets the smartphone_final_url of this AdGroupCriterionServiceBiddableAdGroupCriterion.

        <div lang=\"ja\">最終リンク先URL（スマートフォン）です。<br> ADDおよびSET時、このフィールドは省略可能となります。<br> ※空で設定すると、既存の最終リンク先URL（スマートフォン）は削除されます。</div> <div lang=\"en\">Upgraded final URL (Smartphone).<br> This field is optional in ADD and SET operation.<br> *When tag is set blank, existing upgraded Final URL (Smartphone) will be deleted.</div>   # noqa: E501

        :param smartphone_final_url: The smartphone_final_url of this AdGroupCriterionServiceBiddableAdGroupCriterion.  # noqa: E501
        :type: str
        """

        self._smartphone_final_url = smartphone_final_url

    @property
    def final_url(self):
        """Gets the final_url of this AdGroupCriterionServiceBiddableAdGroupCriterion.  # noqa: E501

        <div lang=\"ja\">移行後の最終リンク先URLです。<br> ADDおよびSET時、このフィールドは省略可能となります。※ADD時、移行してtracking Urlを指定している場合は必須となります。<br> ※空で設定すると、既存の移行後の最終リンク先URLは削除されます。</div> <div lang=\"en\">Upgraded final URL.<br> This field is optional in ADD and SET operation. *If upgraded and tracking Url is specified, it is required in ADD operation.<br> *When this is set blank, existing upgraded Final URL will be deleted.</div>   # noqa: E501

        :return: The final_url of this AdGroupCriterionServiceBiddableAdGroupCriterion.  # noqa: E501
        :rtype: str
        """
        return self._final_url

    @final_url.setter
    def final_url(self, final_url):
        """Sets the final_url of this AdGroupCriterionServiceBiddableAdGroupCriterion.

        <div lang=\"ja\">移行後の最終リンク先URLです。<br> ADDおよびSET時、このフィールドは省略可能となります。※ADD時、移行してtracking Urlを指定している場合は必須となります。<br> ※空で設定すると、既存の移行後の最終リンク先URLは削除されます。</div> <div lang=\"en\">Upgraded final URL.<br> This field is optional in ADD and SET operation. *If upgraded and tracking Url is specified, it is required in ADD operation.<br> *When this is set blank, existing upgraded Final URL will be deleted.</div>   # noqa: E501

        :param final_url: The final_url of this AdGroupCriterionServiceBiddableAdGroupCriterion.  # noqa: E501
        :type: str
        """

        self._final_url = final_url

    @property
    def approval_status(self):
        """Gets the approval_status of this AdGroupCriterionServiceBiddableAdGroupCriterion.  # noqa: E501


        :return: The approval_status of this AdGroupCriterionServiceBiddableAdGroupCriterion.  # noqa: E501
        :rtype: AdGroupCriterionServiceApprovalStatus
        """
        return self._approval_status

    @approval_status.setter
    def approval_status(self, approval_status):
        """Sets the approval_status of this AdGroupCriterionServiceBiddableAdGroupCriterion.


        :param approval_status: The approval_status of this AdGroupCriterionServiceBiddableAdGroupCriterion.  # noqa: E501
        :type: AdGroupCriterionServiceApprovalStatus
        """

        self._approval_status = approval_status

    @property
    def bid(self):
        """Gets the bid of this AdGroupCriterionServiceBiddableAdGroupCriterion.  # noqa: E501


        :return: The bid of this AdGroupCriterionServiceBiddableAdGroupCriterion.  # noqa: E501
        :rtype: AdGroupCriterionServiceBid
        """
        return self._bid

    @bid.setter
    def bid(self, bid):
        """Sets the bid of this AdGroupCriterionServiceBiddableAdGroupCriterion.


        :param bid: The bid of this AdGroupCriterionServiceBiddableAdGroupCriterion.  # noqa: E501
        :type: AdGroupCriterionServiceBid
        """

        self._bid = bid

    @property
    def custom_parameters(self):
        """Gets the custom_parameters of this AdGroupCriterionServiceBiddableAdGroupCriterion.  # noqa: E501


        :return: The custom_parameters of this AdGroupCriterionServiceBiddableAdGroupCriterion.  # noqa: E501
        :rtype: AdGroupCriterionServiceCustomParameters
        """
        return self._custom_parameters

    @custom_parameters.setter
    def custom_parameters(self, custom_parameters):
        """Sets the custom_parameters of this AdGroupCriterionServiceBiddableAdGroupCriterion.


        :param custom_parameters: The custom_parameters of this AdGroupCriterionServiceBiddableAdGroupCriterion.  # noqa: E501
        :type: AdGroupCriterionServiceCustomParameters
        """

        self._custom_parameters = custom_parameters

    @property
    def destination_url(self):
        """Gets the destination_url of this AdGroupCriterionServiceBiddableAdGroupCriterion.  # noqa: E501

        <div lang=\"ja\">移行前のカスタムURLです。<br> ADDおよびSET時、このフィールドは省略可能となります。<br> ※空で設定すると、既存の移行前のカスタムURLは削除されます。</div> <div lang=\"en\">Custom URL of before upgrading.<br> This field is optional in ADD and SET operation.<br> *When tag is set blank, existing Custom URL before upgrade will be deleted.</div>   # noqa: E501

        :return: The destination_url of this AdGroupCriterionServiceBiddableAdGroupCriterion.  # noqa: E501
        :rtype: str
        """
        return self._destination_url

    @destination_url.setter
    def destination_url(self, destination_url):
        """Sets the destination_url of this AdGroupCriterionServiceBiddableAdGroupCriterion.

        <div lang=\"ja\">移行前のカスタムURLです。<br> ADDおよびSET時、このフィールドは省略可能となります。<br> ※空で設定すると、既存の移行前のカスタムURLは削除されます。</div> <div lang=\"en\">Custom URL of before upgrading.<br> This field is optional in ADD and SET operation.<br> *When tag is set blank, existing Custom URL before upgrade will be deleted.</div>   # noqa: E501

        :param destination_url: The destination_url of this AdGroupCriterionServiceBiddableAdGroupCriterion.  # noqa: E501
        :type: str
        """

        self._destination_url = destination_url

    @property
    def disapproval_reason_codes(self):
        """Gets the disapproval_reason_codes of this AdGroupCriterionServiceBiddableAdGroupCriterion.  # noqa: E501

        <div lang=\"ja\">審査否認コードです。<br> (コード詳細は、DictionaryServiceのgetDisapprovalReasonのレスポンスを参照)</div> <div lang=\"en\">Code of disapproval reason.<br> (Refer to DictionaryService getDisapprovalReason response for details)</div>   # noqa: E501

        :return: The disapproval_reason_codes of this AdGroupCriterionServiceBiddableAdGroupCriterion.  # noqa: E501
        :rtype: list[str]
        """
        return self._disapproval_reason_codes

    @disapproval_reason_codes.setter
    def disapproval_reason_codes(self, disapproval_reason_codes):
        """Sets the disapproval_reason_codes of this AdGroupCriterionServiceBiddableAdGroupCriterion.

        <div lang=\"ja\">審査否認コードです。<br> (コード詳細は、DictionaryServiceのgetDisapprovalReasonのレスポンスを参照)</div> <div lang=\"en\">Code of disapproval reason.<br> (Refer to DictionaryService getDisapprovalReason response for details)</div>   # noqa: E501

        :param disapproval_reason_codes: The disapproval_reason_codes of this AdGroupCriterionServiceBiddableAdGroupCriterion.  # noqa: E501
        :type: list[str]
        """

        self._disapproval_reason_codes = disapproval_reason_codes

    @property
    def review_smartphone_final_url(self):
        """Gets the review_smartphone_final_url of this AdGroupCriterionServiceBiddableAdGroupCriterion.  # noqa: E501

        <div lang=\"ja\">配信審査中の最終リンク先URL（スマートフォン）です。</div> <div lang=\"en\">Upgraded final URL (Smartphone), in review.</div>   # noqa: E501

        :return: The review_smartphone_final_url of this AdGroupCriterionServiceBiddableAdGroupCriterion.  # noqa: E501
        :rtype: str
        """
        return self._review_smartphone_final_url

    @review_smartphone_final_url.setter
    def review_smartphone_final_url(self, review_smartphone_final_url):
        """Sets the review_smartphone_final_url of this AdGroupCriterionServiceBiddableAdGroupCriterion.

        <div lang=\"ja\">配信審査中の最終リンク先URL（スマートフォン）です。</div> <div lang=\"en\">Upgraded final URL (Smartphone), in review.</div>   # noqa: E501

        :param review_smartphone_final_url: The review_smartphone_final_url of this AdGroupCriterionServiceBiddableAdGroupCriterion.  # noqa: E501
        :type: str
        """

        self._review_smartphone_final_url = review_smartphone_final_url

    @property
    def review_final_url(self):
        """Gets the review_final_url of this AdGroupCriterionServiceBiddableAdGroupCriterion.  # noqa: E501

        <div lang=\"ja\">移行後の配信審査中の最終リンク先URLです。</div> <div lang=\"en\">Upgraded final URL, in review.</div>   # noqa: E501

        :return: The review_final_url of this AdGroupCriterionServiceBiddableAdGroupCriterion.  # noqa: E501
        :rtype: str
        """
        return self._review_final_url

    @review_final_url.setter
    def review_final_url(self, review_final_url):
        """Sets the review_final_url of this AdGroupCriterionServiceBiddableAdGroupCriterion.

        <div lang=\"ja\">移行後の配信審査中の最終リンク先URLです。</div> <div lang=\"en\">Upgraded final URL, in review.</div>   # noqa: E501

        :param review_final_url: The review_final_url of this AdGroupCriterionServiceBiddableAdGroupCriterion.  # noqa: E501
        :type: str
        """

        self._review_final_url = review_final_url

    @property
    def review_custom_parameters(self):
        """Gets the review_custom_parameters of this AdGroupCriterionServiceBiddableAdGroupCriterion.  # noqa: E501


        :return: The review_custom_parameters of this AdGroupCriterionServiceBiddableAdGroupCriterion.  # noqa: E501
        :rtype: AdGroupCriterionServiceCustomParameters
        """
        return self._review_custom_parameters

    @review_custom_parameters.setter
    def review_custom_parameters(self, review_custom_parameters):
        """Sets the review_custom_parameters of this AdGroupCriterionServiceBiddableAdGroupCriterion.


        :param review_custom_parameters: The review_custom_parameters of this AdGroupCriterionServiceBiddableAdGroupCriterion.  # noqa: E501
        :type: AdGroupCriterionServiceCustomParameters
        """

        self._review_custom_parameters = review_custom_parameters

    @property
    def review_destination_url(self):
        """Gets the review_destination_url of this AdGroupCriterionServiceBiddableAdGroupCriterion.  # noqa: E501

        <div lang=\"ja\">移行前の配信審査中のカスタムURLです。</div> <div lang=\"en\">Custom URL of before upgrading, in review.</div>   # noqa: E501

        :return: The review_destination_url of this AdGroupCriterionServiceBiddableAdGroupCriterion.  # noqa: E501
        :rtype: str
        """
        return self._review_destination_url

    @review_destination_url.setter
    def review_destination_url(self, review_destination_url):
        """Sets the review_destination_url of this AdGroupCriterionServiceBiddableAdGroupCriterion.

        <div lang=\"ja\">移行前の配信審査中のカスタムURLです。</div> <div lang=\"en\">Custom URL of before upgrading, in review.</div>   # noqa: E501

        :param review_destination_url: The review_destination_url of this AdGroupCriterionServiceBiddableAdGroupCriterion.  # noqa: E501
        :type: str
        """

        self._review_destination_url = review_destination_url

    @property
    def review_tracking_url(self):
        """Gets the review_tracking_url of this AdGroupCriterionServiceBiddableAdGroupCriterion.  # noqa: E501

        <div lang=\"ja\">配信審査中のトラッキングURLです。</div> <div lang=\"en\">Tracking URL, in review.</div>   # noqa: E501

        :return: The review_tracking_url of this AdGroupCriterionServiceBiddableAdGroupCriterion.  # noqa: E501
        :rtype: str
        """
        return self._review_tracking_url

    @review_tracking_url.setter
    def review_tracking_url(self, review_tracking_url):
        """Sets the review_tracking_url of this AdGroupCriterionServiceBiddableAdGroupCriterion.

        <div lang=\"ja\">配信審査中のトラッキングURLです。</div> <div lang=\"en\">Tracking URL, in review.</div>   # noqa: E501

        :param review_tracking_url: The review_tracking_url of this AdGroupCriterionServiceBiddableAdGroupCriterion.  # noqa: E501
        :type: str
        """

        self._review_tracking_url = review_tracking_url

    @property
    def tracking_url(self):
        """Gets the tracking_url of this AdGroupCriterionServiceBiddableAdGroupCriterion.  # noqa: E501

        <div lang=\"ja\">トラッキングURLです。<br> ADDおよびSET時、このフィールドは省略可能となります。<br> ※空で設定すると、既存のトラッキングURLは削除されます。</div> <div lang=\"en\">Tracking URL.<br> This field is optional in ADD and SET operation.<br> *When tag is set blank, existing Tracking URL will be deleted.</div>   # noqa: E501

        :return: The tracking_url of this AdGroupCriterionServiceBiddableAdGroupCriterion.  # noqa: E501
        :rtype: str
        """
        return self._tracking_url

    @tracking_url.setter
    def tracking_url(self, tracking_url):
        """Sets the tracking_url of this AdGroupCriterionServiceBiddableAdGroupCriterion.

        <div lang=\"ja\">トラッキングURLです。<br> ADDおよびSET時、このフィールドは省略可能となります。<br> ※空で設定すると、既存のトラッキングURLは削除されます。</div> <div lang=\"en\">Tracking URL.<br> This field is optional in ADD and SET operation.<br> *When tag is set blank, existing Tracking URL will be deleted.</div>   # noqa: E501

        :param tracking_url: The tracking_url of this AdGroupCriterionServiceBiddableAdGroupCriterion.  # noqa: E501
        :type: str
        """

        self._tracking_url = tracking_url

    @property
    def user_status(self):
        """Gets the user_status of this AdGroupCriterionServiceBiddableAdGroupCriterion.  # noqa: E501


        :return: The user_status of this AdGroupCriterionServiceBiddableAdGroupCriterion.  # noqa: E501
        :rtype: AdGroupCriterionServiceUserStatus
        """
        return self._user_status

    @user_status.setter
    def user_status(self, user_status):
        """Sets the user_status of this AdGroupCriterionServiceBiddableAdGroupCriterion.


        :param user_status: The user_status of this AdGroupCriterionServiceBiddableAdGroupCriterion.  # noqa: E501
        :type: AdGroupCriterionServiceUserStatus
        """

        self._user_status = user_status

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AdGroupCriterionServiceBiddableAdGroupCriterion):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, AdGroupCriterionServiceBiddableAdGroupCriterion):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Yahoo!広告 検索広告 API リファレンス / Yahoo! JAPAN Ads Search Ads API Reference

    <div lang=\"ja\">Yahoo!広告 検索広告 APIのWebサービスについて説明します。</div> <div lang=\"en\">Search Ads API Web Services supported in Yahoo! JAPAN Ads API.</div> <div><a target=\"_blank\" href=\"https://github.com/yahoojp-marketing/ads-search-api-documents/blob/master/design/v12/Route.yaml\">OpenAPI Specification</a></div> <div lang=\"ja\"><a target=\"_blank\" href=\"https://github.com/yahoojp-marketing/ads-search-api-documents/blob/master/bestpractice/ja\">Best Practice</a></div> <div lang=\"en\"><a target=\"_blank\" href=\"https://github.com/yahoojp-marketing/ads-search-api-documents/blob/master/bestpractice/en\">Best Practice</a></div>   # noqa: E501

    The version of the OpenAPI document: v12
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from yahoo_search_api_v12.configuration import Configuration


class CampaignServiceDynamicAdsForSearchSetting(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'feed_ids': 'list[int]',
        'page_feed_asset_set_ids': 'list[int]',
        'domain': 'str',
        'das_use_urls_type': 'CampaignServiceDasUseUrlsType'
    }

    attribute_map = {
        'feed_ids': 'feedIds',
        'page_feed_asset_set_ids': 'pageFeedAssetSetIds',
        'domain': 'domain',
        'das_use_urls_type': 'dasUseUrlsType'
    }

    def __init__(self, feed_ids=None, page_feed_asset_set_ids=None, domain=None, das_use_urls_type=None, local_vars_configuration=None):  # noqa: E501
        """CampaignServiceDynamicAdsForSearchSetting - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._feed_ids = None
        self._page_feed_asset_set_ids = None
        self._domain = None
        self._das_use_urls_type = None
        self.discriminator = None

        self.feed_ids = feed_ids
        self.page_feed_asset_set_ids = page_feed_asset_set_ids
        self.domain = domain
        self.das_use_urls_type = das_use_urls_type

    @property
    def feed_ids(self):
        """Gets the feed_ids of this CampaignServiceDynamicAdsForSearchSetting.  # noqa: E501

        <div lang=\"ja\">   キャンペーンで使用するページフィードIDです。<br>   ※現在このフィールドは参照のみ可能です。ページフィードを設定する場合は、pageFeedAssetSetIdsをご利用ください。 </div> <div lang=\"en\">   Page Feed ID for campaign.<br>   *Currently, this field is read-only. To set up page feeds, please use pageFeedAssetSetIds. </div>   # noqa: E501

        :return: The feed_ids of this CampaignServiceDynamicAdsForSearchSetting.  # noqa: E501
        :rtype: list[int]
        """
        return self._feed_ids

    @feed_ids.setter
    def feed_ids(self, feed_ids):
        """Sets the feed_ids of this CampaignServiceDynamicAdsForSearchSetting.

        <div lang=\"ja\">   キャンペーンで使用するページフィードIDです。<br>   ※現在このフィールドは参照のみ可能です。ページフィードを設定する場合は、pageFeedAssetSetIdsをご利用ください。 </div> <div lang=\"en\">   Page Feed ID for campaign.<br>   *Currently, this field is read-only. To set up page feeds, please use pageFeedAssetSetIds. </div>   # noqa: E501

        :param feed_ids: The feed_ids of this CampaignServiceDynamicAdsForSearchSetting.  # noqa: E501
        :type: list[int]
        """

        self._feed_ids = feed_ids

    @property
    def page_feed_asset_set_ids(self):
        """Gets the page_feed_asset_set_ids of this CampaignServiceDynamicAdsForSearchSetting.  # noqa: E501

        <div lang=\"ja\">   キャンペーンで使用するページフィードアセットセットIDです。<br>   ADD時およびSET時、DasUseUrlsTypeがUSE_SUPPLIED_URLS_ONLYまたはDOMAIN_AND_SUPPLIED_URLSの場合、このフィールドは必須となります。 </div> <div lang=\"en\">   PageFeedAssetSet ID for campaign.<br>   In ADD and SET operation, If DasUseUrlsType is USE_SUPPLIED_URLS_ONLY or DOMAIN_AND_SUPPLIED_URLS, this field is required. </div>   # noqa: E501

        :return: The page_feed_asset_set_ids of this CampaignServiceDynamicAdsForSearchSetting.  # noqa: E501
        :rtype: list[int]
        """
        return self._page_feed_asset_set_ids

    @page_feed_asset_set_ids.setter
    def page_feed_asset_set_ids(self, page_feed_asset_set_ids):
        """Sets the page_feed_asset_set_ids of this CampaignServiceDynamicAdsForSearchSetting.

        <div lang=\"ja\">   キャンペーンで使用するページフィードアセットセットIDです。<br>   ADD時およびSET時、DasUseUrlsTypeがUSE_SUPPLIED_URLS_ONLYまたはDOMAIN_AND_SUPPLIED_URLSの場合、このフィールドは必須となります。 </div> <div lang=\"en\">   PageFeedAssetSet ID for campaign.<br>   In ADD and SET operation, If DasUseUrlsType is USE_SUPPLIED_URLS_ONLY or DOMAIN_AND_SUPPLIED_URLS, this field is required. </div>   # noqa: E501

        :param page_feed_asset_set_ids: The page_feed_asset_set_ids of this CampaignServiceDynamicAdsForSearchSetting.  # noqa: E501
        :type: list[int]
        """

        self._page_feed_asset_set_ids = page_feed_asset_set_ids

    @property
    def domain(self):
        """Gets the domain of this CampaignServiceDynamicAdsForSearchSetting.  # noqa: E501

        <div lang=\"ja\">   ドメインです。<br>   ADDおよびSET時、DasUseUrlsTypeがTOP_DOMAIN_ONLYまたはDOMAIN_AND_SUPPLIED_URLSの場合、このフィールドは必須となります。 </div> <div lang=\"en\">   Domain.<br>   If DasUseUrlsType is TOP_DOMAIN_ONLY or DOMAIN_AND_SUPPLIED_URLS, this field is required in ADD and SET operation. </div>   # noqa: E501

        :return: The domain of this CampaignServiceDynamicAdsForSearchSetting.  # noqa: E501
        :rtype: str
        """
        return self._domain

    @domain.setter
    def domain(self, domain):
        """Sets the domain of this CampaignServiceDynamicAdsForSearchSetting.

        <div lang=\"ja\">   ドメインです。<br>   ADDおよびSET時、DasUseUrlsTypeがTOP_DOMAIN_ONLYまたはDOMAIN_AND_SUPPLIED_URLSの場合、このフィールドは必須となります。 </div> <div lang=\"en\">   Domain.<br>   If DasUseUrlsType is TOP_DOMAIN_ONLY or DOMAIN_AND_SUPPLIED_URLS, this field is required in ADD and SET operation. </div>   # noqa: E501

        :param domain: The domain of this CampaignServiceDynamicAdsForSearchSetting.  # noqa: E501
        :type: str
        """

        self._domain = domain

    @property
    def das_use_urls_type(self):
        """Gets the das_use_urls_type of this CampaignServiceDynamicAdsForSearchSetting.  # noqa: E501


        :return: The das_use_urls_type of this CampaignServiceDynamicAdsForSearchSetting.  # noqa: E501
        :rtype: CampaignServiceDasUseUrlsType
        """
        return self._das_use_urls_type

    @das_use_urls_type.setter
    def das_use_urls_type(self, das_use_urls_type):
        """Sets the das_use_urls_type of this CampaignServiceDynamicAdsForSearchSetting.


        :param das_use_urls_type: The das_use_urls_type of this CampaignServiceDynamicAdsForSearchSetting.  # noqa: E501
        :type: CampaignServiceDasUseUrlsType
        """

        self._das_use_urls_type = das_use_urls_type

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CampaignServiceDynamicAdsForSearchSetting):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, CampaignServiceDynamicAdsForSearchSetting):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Yahoo!広告 検索広告 API リファレンス / Yahoo! JAPAN Ads Search Ads API Reference

    <div lang=\"ja\">Yahoo!広告 検索広告 APIのWebサービスについて説明します。</div> <div lang=\"en\">Search Ads API Web Services supported in Yahoo! JAPAN Ads API.</div> <div><a target=\"_blank\" href=\"https://github.com/yahoojp-marketing/ads-search-api-documents/blob/master/design/v12/Route.yaml\">OpenAPI Specification</a></div> <div lang=\"ja\"><a target=\"_blank\" href=\"https://github.com/yahoojp-marketing/ads-search-api-documents/blob/master/bestpractice/ja\">Best Practice</a></div> <div lang=\"en\"><a target=\"_blank\" href=\"https://github.com/yahoojp-marketing/ads-search-api-documents/blob/master/bestpractice/en\">Best Practice</a></div>   # noqa: E501

    The version of the OpenAPI document: v12
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from yahoo_search_api_v12.configuration import Configuration


class CampaignTargetServiceLocationTarget(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'city_name_en': 'str',
        'city_name_ja': 'str',
        'excluded_type': 'CampaignTargetServiceExcludedType',
        'province_name_en': 'str',
        'province_name_ja': 'str',
        'targeting_status': 'CampaignTargetServiceTargetingStatus'
    }

    attribute_map = {
        'city_name_en': 'cityNameEN',
        'city_name_ja': 'cityNameJA',
        'excluded_type': 'excludedType',
        'province_name_en': 'provinceNameEN',
        'province_name_ja': 'provinceNameJA',
        'targeting_status': 'targetingStatus'
    }

    def __init__(self, city_name_en=None, city_name_ja=None, excluded_type=None, province_name_en=None, province_name_ja=None, targeting_status=None, local_vars_configuration=None):  # noqa: E501
        """CampaignTargetServiceLocationTarget - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._city_name_en = None
        self._city_name_ja = None
        self._excluded_type = None
        self._province_name_en = None
        self._province_name_ja = None
        self._targeting_status = None
        self.discriminator = None

        self.city_name_en = city_name_en
        self.city_name_ja = city_name_ja
        self.excluded_type = excluded_type
        self.province_name_en = province_name_en
        self.province_name_ja = province_name_ja
        self.targeting_status = targeting_status

    @property
    def city_name_en(self):
        """Gets the city_name_en of this CampaignTargetServiceLocationTarget.  # noqa: E501

        <div lang=\"ja\">市区町村名（英語）です。<br> このフィールドは、レスポンスの際に返却されますが、リクエストの際には無視されます。</div> <div lang=\"en\">City(English).<br> Although this field will be returned in the response, it will be ignored on input.</div>   # noqa: E501

        :return: The city_name_en of this CampaignTargetServiceLocationTarget.  # noqa: E501
        :rtype: str
        """
        return self._city_name_en

    @city_name_en.setter
    def city_name_en(self, city_name_en):
        """Sets the city_name_en of this CampaignTargetServiceLocationTarget.

        <div lang=\"ja\">市区町村名（英語）です。<br> このフィールドは、レスポンスの際に返却されますが、リクエストの際には無視されます。</div> <div lang=\"en\">City(English).<br> Although this field will be returned in the response, it will be ignored on input.</div>   # noqa: E501

        :param city_name_en: The city_name_en of this CampaignTargetServiceLocationTarget.  # noqa: E501
        :type: str
        """

        self._city_name_en = city_name_en

    @property
    def city_name_ja(self):
        """Gets the city_name_ja of this CampaignTargetServiceLocationTarget.  # noqa: E501

        <div lang=\"ja\">市区町村名（日本語）です。<br> このフィールドは、レスポンスの際に返却されますが、リクエストの際には無視されます。</div> <div lang=\"en\">City(Japanese).<br> Although this field will be returned in the response, it will be ignored on input.</div>   # noqa: E501

        :return: The city_name_ja of this CampaignTargetServiceLocationTarget.  # noqa: E501
        :rtype: str
        """
        return self._city_name_ja

    @city_name_ja.setter
    def city_name_ja(self, city_name_ja):
        """Sets the city_name_ja of this CampaignTargetServiceLocationTarget.

        <div lang=\"ja\">市区町村名（日本語）です。<br> このフィールドは、レスポンスの際に返却されますが、リクエストの際には無視されます。</div> <div lang=\"en\">City(Japanese).<br> Although this field will be returned in the response, it will be ignored on input.</div>   # noqa: E501

        :param city_name_ja: The city_name_ja of this CampaignTargetServiceLocationTarget.  # noqa: E501
        :type: str
        """

        self._city_name_ja = city_name_ja

    @property
    def excluded_type(self):
        """Gets the excluded_type of this CampaignTargetServiceLocationTarget.  # noqa: E501


        :return: The excluded_type of this CampaignTargetServiceLocationTarget.  # noqa: E501
        :rtype: CampaignTargetServiceExcludedType
        """
        return self._excluded_type

    @excluded_type.setter
    def excluded_type(self, excluded_type):
        """Sets the excluded_type of this CampaignTargetServiceLocationTarget.


        :param excluded_type: The excluded_type of this CampaignTargetServiceLocationTarget.  # noqa: E501
        :type: CampaignTargetServiceExcludedType
        """

        self._excluded_type = excluded_type

    @property
    def province_name_en(self):
        """Gets the province_name_en of this CampaignTargetServiceLocationTarget.  # noqa: E501

        <div lang=\"ja\">都道府県名（英語）です。<br> このフィールドは、レスポンスの際に返却されますが、リクエストの際には無視されます。</div> <div lang=\"en\">Prefecture(English).<br> Although this field will be returned in the response, it will be ignored on input.</div>   # noqa: E501

        :return: The province_name_en of this CampaignTargetServiceLocationTarget.  # noqa: E501
        :rtype: str
        """
        return self._province_name_en

    @province_name_en.setter
    def province_name_en(self, province_name_en):
        """Sets the province_name_en of this CampaignTargetServiceLocationTarget.

        <div lang=\"ja\">都道府県名（英語）です。<br> このフィールドは、レスポンスの際に返却されますが、リクエストの際には無視されます。</div> <div lang=\"en\">Prefecture(English).<br> Although this field will be returned in the response, it will be ignored on input.</div>   # noqa: E501

        :param province_name_en: The province_name_en of this CampaignTargetServiceLocationTarget.  # noqa: E501
        :type: str
        """

        self._province_name_en = province_name_en

    @property
    def province_name_ja(self):
        """Gets the province_name_ja of this CampaignTargetServiceLocationTarget.  # noqa: E501

        <div lang=\"ja\">都道府県名（日本語）です。<br> このフィールドは、レスポンスの際に返却されますが、リクエストの際には無視されます。</div> <div lang=\"en\">Prefecture(Japanese).<br> Although this field will be returned in the response, it will be ignored on input.</div>   # noqa: E501

        :return: The province_name_ja of this CampaignTargetServiceLocationTarget.  # noqa: E501
        :rtype: str
        """
        return self._province_name_ja

    @province_name_ja.setter
    def province_name_ja(self, province_name_ja):
        """Sets the province_name_ja of this CampaignTargetServiceLocationTarget.

        <div lang=\"ja\">都道府県名（日本語）です。<br> このフィールドは、レスポンスの際に返却されますが、リクエストの際には無視されます。</div> <div lang=\"en\">Prefecture(Japanese).<br> Although this field will be returned in the response, it will be ignored on input.</div>   # noqa: E501

        :param province_name_ja: The province_name_ja of this CampaignTargetServiceLocationTarget.  # noqa: E501
        :type: str
        """

        self._province_name_ja = province_name_ja

    @property
    def targeting_status(self):
        """Gets the targeting_status of this CampaignTargetServiceLocationTarget.  # noqa: E501


        :return: The targeting_status of this CampaignTargetServiceLocationTarget.  # noqa: E501
        :rtype: CampaignTargetServiceTargetingStatus
        """
        return self._targeting_status

    @targeting_status.setter
    def targeting_status(self, targeting_status):
        """Sets the targeting_status of this CampaignTargetServiceLocationTarget.


        :param targeting_status: The targeting_status of this CampaignTargetServiceLocationTarget.  # noqa: E501
        :type: CampaignTargetServiceTargetingStatus
        """

        self._targeting_status = targeting_status

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CampaignTargetServiceLocationTarget):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, CampaignTargetServiceLocationTarget):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Yahoo!広告 検索広告 API リファレンス / Yahoo! JAPAN Ads Search Ads API Reference

    <div lang=\"ja\">Yahoo!広告 検索広告 APIのWebサービスについて説明します。</div> <div lang=\"en\">Search Ads API Web Services supported in Yahoo! JAPAN Ads API.</div> <div><a target=\"_blank\" href=\"https://github.com/yahoojp-marketing/ads-search-api-documents/blob/master/design/v12/Route.yaml\">OpenAPI Specification</a></div> <div lang=\"ja\"><a target=\"_blank\" href=\"https://github.com/yahoojp-marketing/ads-search-api-documents/blob/master/bestpractice/ja\">Best Practice</a></div> <div lang=\"en\"><a target=\"_blank\" href=\"https://github.com/yahoojp-marketing/ads-search-api-documents/blob/master/bestpractice/en\">Best Practice</a></div>   # noqa: E501

    The version of the OpenAPI document: v12
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from yahoo_search_api_v12.configuration import Configuration


class ReportDefinition(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'account_id': 'int',
        'complete_time': 'str',
        'date_range': 'ReportDefinitionServiceReportDateRange',
        'fields': 'list[str]',
        'filters': 'list[ReportDefinitionServiceReportFilter]',
        'report_compress_type': 'ReportDefinitionServiceReportCompressType',
        'report_date_range_type': 'ReportDefinitionServiceReportDateRangeType',
        'report_decimal_part_display_type': 'ReportDefinitionServiceReportDecimalPartDisplayType',
        'report_download_encode': 'ReportDefinitionServiceReportDownloadEncode',
        'report_download_format': 'ReportDefinitionServiceReportDownloadFormat',
        'report_include_deleted': 'ReportDefinitionServiceReportIncludeDeleted',
        'report_job_error_detail': 'str',
        'report_job_id': 'int',
        'report_job_status': 'ReportDefinitionServiceReportJobStatus',
        'report_language': 'ReportDefinitionServiceReportLanguage',
        'report_name': 'str',
        'report_skip_column_header': 'ReportDefinitionServiceReportSkipColumnHeader',
        'report_skip_report_summary': 'ReportDefinitionServiceReportSkipReportSummary',
        'report_type': 'ReportDefinitionServiceReportType',
        'request_time': 'str',
        'sort_fields': 'list[ReportDefinitionServiceReportSortField]'
    }

    attribute_map = {
        'account_id': 'accountId',
        'complete_time': 'completeTime',
        'date_range': 'dateRange',
        'fields': 'fields',
        'filters': 'filters',
        'report_compress_type': 'reportCompressType',
        'report_date_range_type': 'reportDateRangeType',
        'report_decimal_part_display_type': 'reportDecimalPartDisplayType',
        'report_download_encode': 'reportDownloadEncode',
        'report_download_format': 'reportDownloadFormat',
        'report_include_deleted': 'reportIncludeDeleted',
        'report_job_error_detail': 'reportJobErrorDetail',
        'report_job_id': 'reportJobId',
        'report_job_status': 'reportJobStatus',
        'report_language': 'reportLanguage',
        'report_name': 'reportName',
        'report_skip_column_header': 'reportSkipColumnHeader',
        'report_skip_report_summary': 'reportSkipReportSummary',
        'report_type': 'reportType',
        'request_time': 'requestTime',
        'sort_fields': 'sortFields'
    }

    def __init__(self, account_id=None, complete_time=None, date_range=None, fields=None, filters=None, report_compress_type=None, report_date_range_type=None, report_decimal_part_display_type=None, report_download_encode=None, report_download_format=None, report_include_deleted=None, report_job_error_detail=None, report_job_id=None, report_job_status=None, report_language=None, report_name=None, report_skip_column_header=None, report_skip_report_summary=None, report_type=None, request_time=None, sort_fields=None, local_vars_configuration=None):  # noqa: E501
        """ReportDefinition - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._account_id = None
        self._complete_time = None
        self._date_range = None
        self._fields = None
        self._filters = None
        self._report_compress_type = None
        self._report_date_range_type = None
        self._report_decimal_part_display_type = None
        self._report_download_encode = None
        self._report_download_format = None
        self._report_include_deleted = None
        self._report_job_error_detail = None
        self._report_job_id = None
        self._report_job_status = None
        self._report_language = None
        self._report_name = None
        self._report_skip_column_header = None
        self._report_skip_report_summary = None
        self._report_type = None
        self._request_time = None
        self._sort_fields = None
        self.discriminator = None

        self.account_id = account_id
        self.complete_time = complete_time
        self.date_range = date_range
        self.fields = fields
        self.filters = filters
        self.report_compress_type = report_compress_type
        self.report_date_range_type = report_date_range_type
        self.report_decimal_part_display_type = report_decimal_part_display_type
        self.report_download_encode = report_download_encode
        self.report_download_format = report_download_format
        self.report_include_deleted = report_include_deleted
        self.report_job_error_detail = report_job_error_detail
        self.report_job_id = report_job_id
        self.report_job_status = report_job_status
        self.report_language = report_language
        self.report_name = report_name
        self.report_skip_column_header = report_skip_column_header
        self.report_skip_report_summary = report_skip_report_summary
        self.report_type = report_type
        self.request_time = request_time
        self.sort_fields = sort_fields

    @property
    def account_id(self):
        """Gets the account_id of this ReportDefinition.  # noqa: E501

        <div lang=\"ja\">アカウントIDです。</div> <div lang=\"en\">Account ID.</div>   # noqa: E501

        :return: The account_id of this ReportDefinition.  # noqa: E501
        :rtype: int
        """
        return self._account_id

    @account_id.setter
    def account_id(self, account_id):
        """Sets the account_id of this ReportDefinition.

        <div lang=\"ja\">アカウントIDです。</div> <div lang=\"en\">Account ID.</div>   # noqa: E501

        :param account_id: The account_id of this ReportDefinition.  # noqa: E501
        :type: int
        """

        self._account_id = account_id

    @property
    def complete_time(self):
        """Gets the complete_time of this ReportDefinition.  # noqa: E501

        <div lang=\"ja\">ジョブの完了時刻です。<br> ※YYYY/MM/DD hh:mm:ss形式になります。<br> ※hhは24時間表記になります。</div> <div lang=\"en\">Completion time of Report Job request.<br> *Displays in YYYY/MM/DD hh:mm:ss form.<br> *hh will display in 24-hour time.</div>   # noqa: E501

        :return: The complete_time of this ReportDefinition.  # noqa: E501
        :rtype: str
        """
        return self._complete_time

    @complete_time.setter
    def complete_time(self, complete_time):
        """Sets the complete_time of this ReportDefinition.

        <div lang=\"ja\">ジョブの完了時刻です。<br> ※YYYY/MM/DD hh:mm:ss形式になります。<br> ※hhは24時間表記になります。</div> <div lang=\"en\">Completion time of Report Job request.<br> *Displays in YYYY/MM/DD hh:mm:ss form.<br> *hh will display in 24-hour time.</div>   # noqa: E501

        :param complete_time: The complete_time of this ReportDefinition.  # noqa: E501
        :type: str
        """

        self._complete_time = complete_time

    @property
    def date_range(self):
        """Gets the date_range of this ReportDefinition.  # noqa: E501


        :return: The date_range of this ReportDefinition.  # noqa: E501
        :rtype: ReportDefinitionServiceReportDateRange
        """
        return self._date_range

    @date_range.setter
    def date_range(self, date_range):
        """Sets the date_range of this ReportDefinition.


        :param date_range: The date_range of this ReportDefinition.  # noqa: E501
        :type: ReportDefinitionServiceReportDateRange
        """

        self._date_range = date_range

    @property
    def fields(self):
        """Gets the fields of this ReportDefinition.  # noqa: E501

        <div lang=\"ja\">フィールド（レポートの出力項目名）です。<br> ADD時、このフィールドは必須となります。</div> <div lang=\"en\">Item name of the report.<br> Can appoint the value retrieved from getReportFields.<br> This field is required in ADD operation.</div>   # noqa: E501

        :return: The fields of this ReportDefinition.  # noqa: E501
        :rtype: list[str]
        """
        return self._fields

    @fields.setter
    def fields(self, fields):
        """Sets the fields of this ReportDefinition.

        <div lang=\"ja\">フィールド（レポートの出力項目名）です。<br> ADD時、このフィールドは必須となります。</div> <div lang=\"en\">Item name of the report.<br> Can appoint the value retrieved from getReportFields.<br> This field is required in ADD operation.</div>   # noqa: E501

        :param fields: The fields of this ReportDefinition.  # noqa: E501
        :type: list[str]
        """

        self._fields = fields

    @property
    def filters(self):
        """Gets the filters of this ReportDefinition.  # noqa: E501


        :return: The filters of this ReportDefinition.  # noqa: E501
        :rtype: list[ReportDefinitionServiceReportFilter]
        """
        return self._filters

    @filters.setter
    def filters(self, filters):
        """Sets the filters of this ReportDefinition.


        :param filters: The filters of this ReportDefinition.  # noqa: E501
        :type: list[ReportDefinitionServiceReportFilter]
        """

        self._filters = filters

    @property
    def report_compress_type(self):
        """Gets the report_compress_type of this ReportDefinition.  # noqa: E501


        :return: The report_compress_type of this ReportDefinition.  # noqa: E501
        :rtype: ReportDefinitionServiceReportCompressType
        """
        return self._report_compress_type

    @report_compress_type.setter
    def report_compress_type(self, report_compress_type):
        """Sets the report_compress_type of this ReportDefinition.


        :param report_compress_type: The report_compress_type of this ReportDefinition.  # noqa: E501
        :type: ReportDefinitionServiceReportCompressType
        """

        self._report_compress_type = report_compress_type

    @property
    def report_date_range_type(self):
        """Gets the report_date_range_type of this ReportDefinition.  # noqa: E501


        :return: The report_date_range_type of this ReportDefinition.  # noqa: E501
        :rtype: ReportDefinitionServiceReportDateRangeType
        """
        return self._report_date_range_type

    @report_date_range_type.setter
    def report_date_range_type(self, report_date_range_type):
        """Sets the report_date_range_type of this ReportDefinition.


        :param report_date_range_type: The report_date_range_type of this ReportDefinition.  # noqa: E501
        :type: ReportDefinitionServiceReportDateRangeType
        """

        self._report_date_range_type = report_date_range_type

    @property
    def report_decimal_part_display_type(self):
        """Gets the report_decimal_part_display_type of this ReportDefinition.  # noqa: E501


        :return: The report_decimal_part_display_type of this ReportDefinition.  # noqa: E501
        :rtype: ReportDefinitionServiceReportDecimalPartDisplayType
        """
        return self._report_decimal_part_display_type

    @report_decimal_part_display_type.setter
    def report_decimal_part_display_type(self, report_decimal_part_display_type):
        """Sets the report_decimal_part_display_type of this ReportDefinition.


        :param report_decimal_part_display_type: The report_decimal_part_display_type of this ReportDefinition.  # noqa: E501
        :type: ReportDefinitionServiceReportDecimalPartDisplayType
        """

        self._report_decimal_part_display_type = report_decimal_part_display_type

    @property
    def report_download_encode(self):
        """Gets the report_download_encode of this ReportDefinition.  # noqa: E501


        :return: The report_download_encode of this ReportDefinition.  # noqa: E501
        :rtype: ReportDefinitionServiceReportDownloadEncode
        """
        return self._report_download_encode

    @report_download_encode.setter
    def report_download_encode(self, report_download_encode):
        """Sets the report_download_encode of this ReportDefinition.


        :param report_download_encode: The report_download_encode of this ReportDefinition.  # noqa: E501
        :type: ReportDefinitionServiceReportDownloadEncode
        """

        self._report_download_encode = report_download_encode

    @property
    def report_download_format(self):
        """Gets the report_download_format of this ReportDefinition.  # noqa: E501


        :return: The report_download_format of this ReportDefinition.  # noqa: E501
        :rtype: ReportDefinitionServiceReportDownloadFormat
        """
        return self._report_download_format

    @report_download_format.setter
    def report_download_format(self, report_download_format):
        """Sets the report_download_format of this ReportDefinition.


        :param report_download_format: The report_download_format of this ReportDefinition.  # noqa: E501
        :type: ReportDefinitionServiceReportDownloadFormat
        """

        self._report_download_format = report_download_format

    @property
    def report_include_deleted(self):
        """Gets the report_include_deleted of this ReportDefinition.  # noqa: E501


        :return: The report_include_deleted of this ReportDefinition.  # noqa: E501
        :rtype: ReportDefinitionServiceReportIncludeDeleted
        """
        return self._report_include_deleted

    @report_include_deleted.setter
    def report_include_deleted(self, report_include_deleted):
        """Sets the report_include_deleted of this ReportDefinition.


        :param report_include_deleted: The report_include_deleted of this ReportDefinition.  # noqa: E501
        :type: ReportDefinitionServiceReportIncludeDeleted
        """

        self._report_include_deleted = report_include_deleted

    @property
    def report_job_error_detail(self):
        """Gets the report_job_error_detail of this ReportDefinition.  # noqa: E501

        <div lang=\"ja\">レポートジョブのエラー詳細です。</div> <div lang=\"en\">Error details of Report Job.</div>   # noqa: E501

        :return: The report_job_error_detail of this ReportDefinition.  # noqa: E501
        :rtype: str
        """
        return self._report_job_error_detail

    @report_job_error_detail.setter
    def report_job_error_detail(self, report_job_error_detail):
        """Sets the report_job_error_detail of this ReportDefinition.

        <div lang=\"ja\">レポートジョブのエラー詳細です。</div> <div lang=\"en\">Error details of Report Job.</div>   # noqa: E501

        :param report_job_error_detail: The report_job_error_detail of this ReportDefinition.  # noqa: E501
        :type: str
        """

        self._report_job_error_detail = report_job_error_detail

    @property
    def report_job_id(self):
        """Gets the report_job_id of this ReportDefinition.  # noqa: E501

        <div lang=\"ja\">レポートジョブIDです。<br> REMOVE時、このフィールドは必須となります。</div> <div lang=\"en\">Report Job ID.<br> This field is required in REMOVE operation.</div>   # noqa: E501

        :return: The report_job_id of this ReportDefinition.  # noqa: E501
        :rtype: int
        """
        return self._report_job_id

    @report_job_id.setter
    def report_job_id(self, report_job_id):
        """Sets the report_job_id of this ReportDefinition.

        <div lang=\"ja\">レポートジョブIDです。<br> REMOVE時、このフィールドは必須となります。</div> <div lang=\"en\">Report Job ID.<br> This field is required in REMOVE operation.</div>   # noqa: E501

        :param report_job_id: The report_job_id of this ReportDefinition.  # noqa: E501
        :type: int
        """

        self._report_job_id = report_job_id

    @property
    def report_job_status(self):
        """Gets the report_job_status of this ReportDefinition.  # noqa: E501


        :return: The report_job_status of this ReportDefinition.  # noqa: E501
        :rtype: ReportDefinitionServiceReportJobStatus
        """
        return self._report_job_status

    @report_job_status.setter
    def report_job_status(self, report_job_status):
        """Sets the report_job_status of this ReportDefinition.


        :param report_job_status: The report_job_status of this ReportDefinition.  # noqa: E501
        :type: ReportDefinitionServiceReportJobStatus
        """

        self._report_job_status = report_job_status

    @property
    def report_language(self):
        """Gets the report_language of this ReportDefinition.  # noqa: E501


        :return: The report_language of this ReportDefinition.  # noqa: E501
        :rtype: ReportDefinitionServiceReportLanguage
        """
        return self._report_language

    @report_language.setter
    def report_language(self, report_language):
        """Sets the report_language of this ReportDefinition.


        :param report_language: The report_language of this ReportDefinition.  # noqa: E501
        :type: ReportDefinitionServiceReportLanguage
        """

        self._report_language = report_language

    @property
    def report_name(self):
        """Gets the report_name of this ReportDefinition.  # noqa: E501

        <div lang=\"ja\">レポート名称です。<br> ADD時、このフィールドは必須となります。</div> <div lang=\"en\">Name of the report.<br> This field is required in ADD operation.</div>   # noqa: E501

        :return: The report_name of this ReportDefinition.  # noqa: E501
        :rtype: str
        """
        return self._report_name

    @report_name.setter
    def report_name(self, report_name):
        """Sets the report_name of this ReportDefinition.

        <div lang=\"ja\">レポート名称です。<br> ADD時、このフィールドは必須となります。</div> <div lang=\"en\">Name of the report.<br> This field is required in ADD operation.</div>   # noqa: E501

        :param report_name: The report_name of this ReportDefinition.  # noqa: E501
        :type: str
        """

        self._report_name = report_name

    @property
    def report_skip_column_header(self):
        """Gets the report_skip_column_header of this ReportDefinition.  # noqa: E501


        :return: The report_skip_column_header of this ReportDefinition.  # noqa: E501
        :rtype: ReportDefinitionServiceReportSkipColumnHeader
        """
        return self._report_skip_column_header

    @report_skip_column_header.setter
    def report_skip_column_header(self, report_skip_column_header):
        """Sets the report_skip_column_header of this ReportDefinition.


        :param report_skip_column_header: The report_skip_column_header of this ReportDefinition.  # noqa: E501
        :type: ReportDefinitionServiceReportSkipColumnHeader
        """

        self._report_skip_column_header = report_skip_column_header

    @property
    def report_skip_report_summary(self):
        """Gets the report_skip_report_summary of this ReportDefinition.  # noqa: E501


        :return: The report_skip_report_summary of this ReportDefinition.  # noqa: E501
        :rtype: ReportDefinitionServiceReportSkipReportSummary
        """
        return self._report_skip_report_summary

    @report_skip_report_summary.setter
    def report_skip_report_summary(self, report_skip_report_summary):
        """Sets the report_skip_report_summary of this ReportDefinition.


        :param report_skip_report_summary: The report_skip_report_summary of this ReportDefinition.  # noqa: E501
        :type: ReportDefinitionServiceReportSkipReportSummary
        """

        self._report_skip_report_summary = report_skip_report_summary

    @property
    def report_type(self):
        """Gets the report_type of this ReportDefinition.  # noqa: E501


        :return: The report_type of this ReportDefinition.  # noqa: E501
        :rtype: ReportDefinitionServiceReportType
        """
        return self._report_type

    @report_type.setter
    def report_type(self, report_type):
        """Sets the report_type of this ReportDefinition.


        :param report_type: The report_type of this ReportDefinition.  # noqa: E501
        :type: ReportDefinitionServiceReportType
        """

        self._report_type = report_type

    @property
    def request_time(self):
        """Gets the request_time of this ReportDefinition.  # noqa: E501

        <div lang=\"ja\">リクエストの到着日時です。<br> このフィールドは、レスポンスの際に返却されますが、リクエストの際には無視されます。<br> ※フォーマット: yyyy/MM/dd HH:mm:ss<br> ※HHは24時間表記になります。</div> <div lang=\"en\">Arrival date and time of your request.<br> Although this field will be returned in the response, it will be ignored on input.<br> *Format: yyyy/MM/dd HH:mm:ss *HH will display in 24-hour time.</div>   # noqa: E501

        :return: The request_time of this ReportDefinition.  # noqa: E501
        :rtype: str
        """
        return self._request_time

    @request_time.setter
    def request_time(self, request_time):
        """Sets the request_time of this ReportDefinition.

        <div lang=\"ja\">リクエストの到着日時です。<br> このフィールドは、レスポンスの際に返却されますが、リクエストの際には無視されます。<br> ※フォーマット: yyyy/MM/dd HH:mm:ss<br> ※HHは24時間表記になります。</div> <div lang=\"en\">Arrival date and time of your request.<br> Although this field will be returned in the response, it will be ignored on input.<br> *Format: yyyy/MM/dd HH:mm:ss *HH will display in 24-hour time.</div>   # noqa: E501

        :param request_time: The request_time of this ReportDefinition.  # noqa: E501
        :type: str
        """

        self._request_time = request_time

    @property
    def sort_fields(self):
        """Gets the sort_fields of this ReportDefinition.  # noqa: E501


        :return: The sort_fields of this ReportDefinition.  # noqa: E501
        :rtype: list[ReportDefinitionServiceReportSortField]
        """
        return self._sort_fields

    @sort_fields.setter
    def sort_fields(self, sort_fields):
        """Sets the sort_fields of this ReportDefinition.


        :param sort_fields: The sort_fields of this ReportDefinition.  # noqa: E501
        :type: list[ReportDefinitionServiceReportSortField]
        """

        self._sort_fields = sort_fields

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ReportDefinition):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ReportDefinition):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Yahoo!広告 検索広告 API リファレンス / Yahoo! JAPAN Ads Search Ads API Reference

    <div lang=\"ja\">Yahoo!広告 検索広告 APIのWebサービスについて説明します。</div> <div lang=\"en\">Search Ads API Web Services supported in Yahoo! JAPAN Ads API.</div> <div><a target=\"_blank\" href=\"https://github.com/yahoojp-marketing/ads-search-api-documents/blob/master/design/v12/Route.yaml\">OpenAPI Specification</a></div> <div lang=\"ja\"><a target=\"_blank\" href=\"https://github.com/yahoojp-marketing/ads-search-api-documents/blob/master/bestpractice/ja\">Best Practice</a></div> <div lang=\"en\"><a target=\"_blank\" href=\"https://github.com/yahoojp-marketing/ads-search-api-documents/blob/master/bestpractice/en\">Best Practice</a></div>   # noqa: E501

    The version of the OpenAPI document: v12
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from yahoo_search_api_v12.configuration import Configuration


class AdGroupAdServiceResponsiveSearchAd(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'headlines': 'list[AdGroupAdServiceHeadlineTextAsset]',
        'descriptions': 'list[AdGroupAdServiceDescriptionTextAsset]',
        'path1': 'str',
        'is_remove_path1': 'AdGroupAdServiceIsRemove',
        'path2': 'str',
        'is_remove_path2': 'AdGroupAdServiceIsRemove',
        'review_headlines': 'list[AdGroupAdServiceHeadlineTextAsset]',
        'review_descriptions': 'list[AdGroupAdServiceDescriptionTextAsset]',
        'review_path1': 'str',
        'review_path2': 'str'
    }

    attribute_map = {
        'headlines': 'headlines',
        'descriptions': 'descriptions',
        'path1': 'path1',
        'is_remove_path1': 'isRemovePath1',
        'path2': 'path2',
        'is_remove_path2': 'isRemovePath2',
        'review_headlines': 'reviewHeadlines',
        'review_descriptions': 'reviewDescriptions',
        'review_path1': 'reviewPath1',
        'review_path2': 'reviewPath2'
    }

    def __init__(self, headlines=None, descriptions=None, path1=None, is_remove_path1=None, path2=None, is_remove_path2=None, review_headlines=None, review_descriptions=None, review_path1=None, review_path2=None, local_vars_configuration=None):  # noqa: E501
        """AdGroupAdServiceResponsiveSearchAd - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._headlines = None
        self._descriptions = None
        self._path1 = None
        self._is_remove_path1 = None
        self._path2 = None
        self._is_remove_path2 = None
        self._review_headlines = None
        self._review_descriptions = None
        self._review_path1 = None
        self._review_path2 = None
        self.discriminator = None

        self.headlines = headlines
        self.descriptions = descriptions
        self.path1 = path1
        self.is_remove_path1 = is_remove_path1
        self.path2 = path2
        self.is_remove_path2 = is_remove_path2
        self.review_headlines = review_headlines
        self.review_descriptions = review_descriptions
        self.review_path1 = review_path1
        self.review_path2 = review_path2

    @property
    def headlines(self):
        """Gets the headlines of this AdGroupAdServiceResponsiveSearchAd.  # noqa: E501

        <div lang=\"ja\">レスポンシブ検索広告で指定するタイトルのテキストアセットを表します。<br> headlines[]には、3~15件の指定が可能です。<br> このフィールドは、ADD時は必須となり、SET時は省略可能となります。</div> <div lang=\"en\">Text asset for the headline that specify in responsive ads for search.<br> 3 to 15 items can be specified for headlines[].<br> This field is required in ADD operation, and will be optional in SET operation.</div>   # noqa: E501

        :return: The headlines of this AdGroupAdServiceResponsiveSearchAd.  # noqa: E501
        :rtype: list[AdGroupAdServiceHeadlineTextAsset]
        """
        return self._headlines

    @headlines.setter
    def headlines(self, headlines):
        """Sets the headlines of this AdGroupAdServiceResponsiveSearchAd.

        <div lang=\"ja\">レスポンシブ検索広告で指定するタイトルのテキストアセットを表します。<br> headlines[]には、3~15件の指定が可能です。<br> このフィールドは、ADD時は必須となり、SET時は省略可能となります。</div> <div lang=\"en\">Text asset for the headline that specify in responsive ads for search.<br> 3 to 15 items can be specified for headlines[].<br> This field is required in ADD operation, and will be optional in SET operation.</div>   # noqa: E501

        :param headlines: The headlines of this AdGroupAdServiceResponsiveSearchAd.  # noqa: E501
        :type: list[AdGroupAdServiceHeadlineTextAsset]
        """

        self._headlines = headlines

    @property
    def descriptions(self):
        """Gets the descriptions of this AdGroupAdServiceResponsiveSearchAd.  # noqa: E501

        <div lang=\"ja\">レスポンシブ検索広告で指定する説明文のテキストアセットを表します。<br> descriptions[]には、2~4件の指定が可能です。<br> このフィールドは、ADD時は必須となり、SET時は省略可能となります。</div> <div lang=\"en\">Text asset for the description that specify in responsive ads for search.<br> 2 to 4 items can be specified for descriptions[].<br> This field is required in ADD operation, and will be optional in SET operation.</div>   # noqa: E501

        :return: The descriptions of this AdGroupAdServiceResponsiveSearchAd.  # noqa: E501
        :rtype: list[AdGroupAdServiceDescriptionTextAsset]
        """
        return self._descriptions

    @descriptions.setter
    def descriptions(self, descriptions):
        """Sets the descriptions of this AdGroupAdServiceResponsiveSearchAd.

        <div lang=\"ja\">レスポンシブ検索広告で指定する説明文のテキストアセットを表します。<br> descriptions[]には、2~4件の指定が可能です。<br> このフィールドは、ADD時は必須となり、SET時は省略可能となります。</div> <div lang=\"en\">Text asset for the description that specify in responsive ads for search.<br> 2 to 4 items can be specified for descriptions[].<br> This field is required in ADD operation, and will be optional in SET operation.</div>   # noqa: E501

        :param descriptions: The descriptions of this AdGroupAdServiceResponsiveSearchAd.  # noqa: E501
        :type: list[AdGroupAdServiceDescriptionTextAsset]
        """

        self._descriptions = descriptions

    @property
    def path1(self):
        """Gets the path1 of this AdGroupAdServiceResponsiveSearchAd.  # noqa: E501

        <div lang=\"ja\">自動作成される表示URLを補足するパスです。<br> ADDおよびSET時、このフィールドは省略可能となります。その際、デフォルト設定値はnullとなります。<br>※path2を指定する場合は、path1は必須です。</div> <div lang=\"en\">The path information which complements display URL generated automatically.<br> This field is optional in ADD and SET operation. The default value will be null.<br>*To specify path2, path1 is required.</div>   # noqa: E501

        :return: The path1 of this AdGroupAdServiceResponsiveSearchAd.  # noqa: E501
        :rtype: str
        """
        return self._path1

    @path1.setter
    def path1(self, path1):
        """Sets the path1 of this AdGroupAdServiceResponsiveSearchAd.

        <div lang=\"ja\">自動作成される表示URLを補足するパスです。<br> ADDおよびSET時、このフィールドは省略可能となります。その際、デフォルト設定値はnullとなります。<br>※path2を指定する場合は、path1は必須です。</div> <div lang=\"en\">The path information which complements display URL generated automatically.<br> This field is optional in ADD and SET operation. The default value will be null.<br>*To specify path2, path1 is required.</div>   # noqa: E501

        :param path1: The path1 of this AdGroupAdServiceResponsiveSearchAd.  # noqa: E501
        :type: str
        """

        self._path1 = path1

    @property
    def is_remove_path1(self):
        """Gets the is_remove_path1 of this AdGroupAdServiceResponsiveSearchAd.  # noqa: E501


        :return: The is_remove_path1 of this AdGroupAdServiceResponsiveSearchAd.  # noqa: E501
        :rtype: AdGroupAdServiceIsRemove
        """
        return self._is_remove_path1

    @is_remove_path1.setter
    def is_remove_path1(self, is_remove_path1):
        """Sets the is_remove_path1 of this AdGroupAdServiceResponsiveSearchAd.


        :param is_remove_path1: The is_remove_path1 of this AdGroupAdServiceResponsiveSearchAd.  # noqa: E501
        :type: AdGroupAdServiceIsRemove
        """

        self._is_remove_path1 = is_remove_path1

    @property
    def path2(self):
        """Gets the path2 of this AdGroupAdServiceResponsiveSearchAd.  # noqa: E501

        <div lang=\"ja\">自動作成される表示URLを補足するパスです。<br> ADDおよびSET時、このフィールドは省略可能となります。その際、デフォルト設定値はnullとなります。<br>※path1を指定していない場合、path2は無視されます。</div> <div lang=\"en\">The path information which complements display URL generated automatically.<br> This field is optional in ADD and SET operation. The default value will be null.<br>*If path1 is not specified, path2 will be ignored.</div>   # noqa: E501

        :return: The path2 of this AdGroupAdServiceResponsiveSearchAd.  # noqa: E501
        :rtype: str
        """
        return self._path2

    @path2.setter
    def path2(self, path2):
        """Sets the path2 of this AdGroupAdServiceResponsiveSearchAd.

        <div lang=\"ja\">自動作成される表示URLを補足するパスです。<br> ADDおよびSET時、このフィールドは省略可能となります。その際、デフォルト設定値はnullとなります。<br>※path1を指定していない場合、path2は無視されます。</div> <div lang=\"en\">The path information which complements display URL generated automatically.<br> This field is optional in ADD and SET operation. The default value will be null.<br>*If path1 is not specified, path2 will be ignored.</div>   # noqa: E501

        :param path2: The path2 of this AdGroupAdServiceResponsiveSearchAd.  # noqa: E501
        :type: str
        """

        self._path2 = path2

    @property
    def is_remove_path2(self):
        """Gets the is_remove_path2 of this AdGroupAdServiceResponsiveSearchAd.  # noqa: E501


        :return: The is_remove_path2 of this AdGroupAdServiceResponsiveSearchAd.  # noqa: E501
        :rtype: AdGroupAdServiceIsRemove
        """
        return self._is_remove_path2

    @is_remove_path2.setter
    def is_remove_path2(self, is_remove_path2):
        """Sets the is_remove_path2 of this AdGroupAdServiceResponsiveSearchAd.


        :param is_remove_path2: The is_remove_path2 of this AdGroupAdServiceResponsiveSearchAd.  # noqa: E501
        :type: AdGroupAdServiceIsRemove
        """

        self._is_remove_path2 = is_remove_path2

    @property
    def review_headlines(self):
        """Gets the review_headlines of this AdGroupAdServiceResponsiveSearchAd.  # noqa: E501

        <div lang=\"ja\">審査中のタイトルのテキストアセットを表します。<br> このフィールドは、リクエストの際には無視されます。<br> 審査中の間のみ、レスポンスの際に返却されます。</div> <div lang=\"en\">Text asset for the headline under review.<br> This field will be ignored on input.<br> It will be returned at the time of response only during the review.</div>   # noqa: E501

        :return: The review_headlines of this AdGroupAdServiceResponsiveSearchAd.  # noqa: E501
        :rtype: list[AdGroupAdServiceHeadlineTextAsset]
        """
        return self._review_headlines

    @review_headlines.setter
    def review_headlines(self, review_headlines):
        """Sets the review_headlines of this AdGroupAdServiceResponsiveSearchAd.

        <div lang=\"ja\">審査中のタイトルのテキストアセットを表します。<br> このフィールドは、リクエストの際には無視されます。<br> 審査中の間のみ、レスポンスの際に返却されます。</div> <div lang=\"en\">Text asset for the headline under review.<br> This field will be ignored on input.<br> It will be returned at the time of response only during the review.</div>   # noqa: E501

        :param review_headlines: The review_headlines of this AdGroupAdServiceResponsiveSearchAd.  # noqa: E501
        :type: list[AdGroupAdServiceHeadlineTextAsset]
        """

        self._review_headlines = review_headlines

    @property
    def review_descriptions(self):
        """Gets the review_descriptions of this AdGroupAdServiceResponsiveSearchAd.  # noqa: E501

        <div lang=\"ja\">審査中の説明文のテキストアセットを表します。<br> このフィールドは、リクエストの際には無視されます。<br> 審査中の間のみ、レスポンスの際に返却されます。</div> <div lang=\"en\">Text asset for the description under review.<br> This field will be ignored on input.<br> It will be returned at the time of response only during the review.</div>   # noqa: E501

        :return: The review_descriptions of this AdGroupAdServiceResponsiveSearchAd.  # noqa: E501
        :rtype: list[AdGroupAdServiceDescriptionTextAsset]
        """
        return self._review_descriptions

    @review_descriptions.setter
    def review_descriptions(self, review_descriptions):
        """Sets the review_descriptions of this AdGroupAdServiceResponsiveSearchAd.

        <div lang=\"ja\">審査中の説明文のテキストアセットを表します。<br> このフィールドは、リクエストの際には無視されます。<br> 審査中の間のみ、レスポンスの際に返却されます。</div> <div lang=\"en\">Text asset for the description under review.<br> This field will be ignored on input.<br> It will be returned at the time of response only during the review.</div>   # noqa: E501

        :param review_descriptions: The review_descriptions of this AdGroupAdServiceResponsiveSearchAd.  # noqa: E501
        :type: list[AdGroupAdServiceDescriptionTextAsset]
        """

        self._review_descriptions = review_descriptions

    @property
    def review_path1(self):
        """Gets the review_path1 of this AdGroupAdServiceResponsiveSearchAd.  # noqa: E501

        <div lang=\"ja\">審査中の自動作成される表示URLを補足するパスです。<br> このフィールドは、リクエストの際には無視されます。<br> 審査中の間のみ、レスポンスの際に返却されます。</div> <div lang=\"en\">The path information which complements display URL generated automatically (Under review).<br> This field will be ignored on input.<br> It will be returned at the time of response only during the review.</div>   # noqa: E501

        :return: The review_path1 of this AdGroupAdServiceResponsiveSearchAd.  # noqa: E501
        :rtype: str
        """
        return self._review_path1

    @review_path1.setter
    def review_path1(self, review_path1):
        """Sets the review_path1 of this AdGroupAdServiceResponsiveSearchAd.

        <div lang=\"ja\">審査中の自動作成される表示URLを補足するパスです。<br> このフィールドは、リクエストの際には無視されます。<br> 審査中の間のみ、レスポンスの際に返却されます。</div> <div lang=\"en\">The path information which complements display URL generated automatically (Under review).<br> This field will be ignored on input.<br> It will be returned at the time of response only during the review.</div>   # noqa: E501

        :param review_path1: The review_path1 of this AdGroupAdServiceResponsiveSearchAd.  # noqa: E501
        :type: str
        """

        self._review_path1 = review_path1

    @property
    def review_path2(self):
        """Gets the review_path2 of this AdGroupAdServiceResponsiveSearchAd.  # noqa: E501

        <div lang=\"ja\">審査中の自動作成される表示URLを補足するパスです。<br> このフィールドは、リクエストの際には無視されます。<br> 審査中の間のみ、レスポンスの際に返却されます。</div> <div lang=\"en\">The path information which complements display URL generated automatically (Under review).<br> This field will be ignored on input.<br> It will be returned at the time of response only during the review.</div>   # noqa: E501

        :return: The review_path2 of this AdGroupAdServiceResponsiveSearchAd.  # noqa: E501
        :rtype: str
        """
        return self._review_path2

    @review_path2.setter
    def review_path2(self, review_path2):
        """Sets the review_path2 of this AdGroupAdServiceResponsiveSearchAd.

        <div lang=\"ja\">審査中の自動作成される表示URLを補足するパスです。<br> このフィールドは、リクエストの際には無視されます。<br> 審査中の間のみ、レスポンスの際に返却されます。</div> <div lang=\"en\">The path information which complements display URL generated automatically (Under review).<br> This field will be ignored on input.<br> It will be returned at the time of response only during the review.</div>   # noqa: E501

        :param review_path2: The review_path2 of this AdGroupAdServiceResponsiveSearchAd.  # noqa: E501
        :type: str
        """

        self._review_path2 = review_path2

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AdGroupAdServiceResponsiveSearchAd):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, AdGroupAdServiceResponsiveSearchAd):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Yahoo!広告 検索広告 API リファレンス / Yahoo! JAPAN Ads Search Ads API Reference

    <div lang=\"ja\">Yahoo!広告 検索広告 APIのWebサービスについて説明します。</div> <div lang=\"en\">Search Ads API Web Services supported in Yahoo! JAPAN Ads API.</div> <div><a target=\"_blank\" href=\"https://github.com/yahoojp-marketing/ads-search-api-documents/blob/master/design/v12/Route.yaml\">OpenAPI Specification</a></div> <div lang=\"ja\"><a target=\"_blank\" href=\"https://github.com/yahoojp-marketing/ads-search-api-documents/blob/master/bestpractice/ja\">Best Practice</a></div> <div lang=\"en\"><a target=\"_blank\" href=\"https://github.com/yahoojp-marketing/ads-search-api-documents/blob/master/bestpractice/en\">Best Practice</a></div>   # noqa: E501

    The version of the OpenAPI document: v12
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from yahoo_search_api_v12.configuration import Configuration


class RetargetingListServiceRuleBaseTargetList(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'end_date': 'str',
        'is_all_visitor_rule': 'RetargetingListServiceIsAllVisitorRule',
        'is_date_specific_rule': 'RetargetingListServiceIsDateSpecificRule',
        'rules': 'list[RetargetingListServiceRuleGroup]',
        'start_date': 'str'
    }

    attribute_map = {
        'end_date': 'endDate',
        'is_all_visitor_rule': 'isAllVisitorRule',
        'is_date_specific_rule': 'isDateSpecificRule',
        'rules': 'rules',
        'start_date': 'startDate'
    }

    def __init__(self, end_date=None, is_all_visitor_rule=None, is_date_specific_rule=None, rules=None, start_date=None, local_vars_configuration=None):  # noqa: E501
        """RetargetingListServiceRuleBaseTargetList - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._end_date = None
        self._is_all_visitor_rule = None
        self._is_date_specific_rule = None
        self._rules = None
        self._start_date = None
        self.discriminator = None

        self.end_date = end_date
        self.is_all_visitor_rule = is_all_visitor_rule
        self.is_date_specific_rule = is_date_specific_rule
        self.rules = rules
        self.start_date = start_date

    @property
    def end_date(self):
        """Gets the end_date of this RetargetingListServiceRuleBaseTargetList.  # noqa: E501

        <div lang=\"ja\">ルール適用終了日です。<br> ※このフィールドの追加と編集は廃止され、現在設定できません。<br> ※YYYYMMDD形式です。<br> ※リクエスト日は2037/12/30まで 指定可能です。</div> <div lang=\"en\">End date of rule setting.<br> *In YYYYMMDD format<br> *Request date can be set up to 2037/12/30<br> *Adding and editing this field is obsolete. Currently not available.</div>   # noqa: E501

        :return: The end_date of this RetargetingListServiceRuleBaseTargetList.  # noqa: E501
        :rtype: str
        """
        return self._end_date

    @end_date.setter
    def end_date(self, end_date):
        """Sets the end_date of this RetargetingListServiceRuleBaseTargetList.

        <div lang=\"ja\">ルール適用終了日です。<br> ※このフィールドの追加と編集は廃止され、現在設定できません。<br> ※YYYYMMDD形式です。<br> ※リクエスト日は2037/12/30まで 指定可能です。</div> <div lang=\"en\">End date of rule setting.<br> *In YYYYMMDD format<br> *Request date can be set up to 2037/12/30<br> *Adding and editing this field is obsolete. Currently not available.</div>   # noqa: E501

        :param end_date: The end_date of this RetargetingListServiceRuleBaseTargetList.  # noqa: E501
        :type: str
        """

        self._end_date = end_date

    @property
    def is_all_visitor_rule(self):
        """Gets the is_all_visitor_rule of this RetargetingListServiceRuleBaseTargetList.  # noqa: E501


        :return: The is_all_visitor_rule of this RetargetingListServiceRuleBaseTargetList.  # noqa: E501
        :rtype: RetargetingListServiceIsAllVisitorRule
        """
        return self._is_all_visitor_rule

    @is_all_visitor_rule.setter
    def is_all_visitor_rule(self, is_all_visitor_rule):
        """Sets the is_all_visitor_rule of this RetargetingListServiceRuleBaseTargetList.


        :param is_all_visitor_rule: The is_all_visitor_rule of this RetargetingListServiceRuleBaseTargetList.  # noqa: E501
        :type: RetargetingListServiceIsAllVisitorRule
        """

        self._is_all_visitor_rule = is_all_visitor_rule

    @property
    def is_date_specific_rule(self):
        """Gets the is_date_specific_rule of this RetargetingListServiceRuleBaseTargetList.  # noqa: E501


        :return: The is_date_specific_rule of this RetargetingListServiceRuleBaseTargetList.  # noqa: E501
        :rtype: RetargetingListServiceIsDateSpecificRule
        """
        return self._is_date_specific_rule

    @is_date_specific_rule.setter
    def is_date_specific_rule(self, is_date_specific_rule):
        """Sets the is_date_specific_rule of this RetargetingListServiceRuleBaseTargetList.


        :param is_date_specific_rule: The is_date_specific_rule of this RetargetingListServiceRuleBaseTargetList.  # noqa: E501
        :type: RetargetingListServiceIsDateSpecificRule
        """

        self._is_date_specific_rule = is_date_specific_rule

    @property
    def rules(self):
        """Gets the rules of this RetargetingListServiceRuleBaseTargetList.  # noqa: E501


        :return: The rules of this RetargetingListServiceRuleBaseTargetList.  # noqa: E501
        :rtype: list[RetargetingListServiceRuleGroup]
        """
        return self._rules

    @rules.setter
    def rules(self, rules):
        """Sets the rules of this RetargetingListServiceRuleBaseTargetList.


        :param rules: The rules of this RetargetingListServiceRuleBaseTargetList.  # noqa: E501
        :type: list[RetargetingListServiceRuleGroup]
        """

        self._rules = rules

    @property
    def start_date(self):
        """Gets the start_date of this RetargetingListServiceRuleBaseTargetList.  # noqa: E501

        <div lang=\"ja\">ルール適用開始日です。<br> ※YYYYMMDD形式です。<br>※リクエスト日は2037/12/30まで 指定可能です。<br> ※このフィールドの追加と編集は廃止され、現在設定できません。</div> <div lang=\"en\">Start date of rule setting.<br> *In YYYYMMDD format<br> *Request date can be set up to 2037/12/30<br> *Adding and editing this field is obsolete. Currently not available.</div>   # noqa: E501

        :return: The start_date of this RetargetingListServiceRuleBaseTargetList.  # noqa: E501
        :rtype: str
        """
        return self._start_date

    @start_date.setter
    def start_date(self, start_date):
        """Sets the start_date of this RetargetingListServiceRuleBaseTargetList.

        <div lang=\"ja\">ルール適用開始日です。<br> ※YYYYMMDD形式です。<br>※リクエスト日は2037/12/30まで 指定可能です。<br> ※このフィールドの追加と編集は廃止され、現在設定できません。</div> <div lang=\"en\">Start date of rule setting.<br> *In YYYYMMDD format<br> *Request date can be set up to 2037/12/30<br> *Adding and editing this field is obsolete. Currently not available.</div>   # noqa: E501

        :param start_date: The start_date of this RetargetingListServiceRuleBaseTargetList.  # noqa: E501
        :type: str
        """

        self._start_date = start_date

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, RetargetingListServiceRuleBaseTargetList):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, RetargetingListServiceRuleBaseTargetList):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Yahoo!広告 検索広告 API リファレンス / Yahoo! JAPAN Ads Search Ads API Reference

    <div lang=\"ja\">Yahoo!広告 検索広告 APIのWebサービスについて説明します。</div> <div lang=\"en\">Search Ads API Web Services supported in Yahoo! JAPAN Ads API.</div> <div><a target=\"_blank\" href=\"https://github.com/yahoojp-marketing/ads-search-api-documents/blob/master/design/v12/Route.yaml\">OpenAPI Specification</a></div> <div lang=\"ja\"><a target=\"_blank\" href=\"https://github.com/yahoojp-marketing/ads-search-api-documents/blob/master/bestpractice/ja\">Best Practice</a></div> <div lang=\"en\"><a target=\"_blank\" href=\"https://github.com/yahoojp-marketing/ads-search-api-documents/blob/master/bestpractice/en\">Best Practice</a></div>   # noqa: E501

    The version of the OpenAPI document: v12
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from yahoo_search_api_v12.configuration import Configuration


class CampaignTargetServiceTarget(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'location_target': 'CampaignTargetServiceLocationTarget',
        'network_target': 'CampaignTargetServiceNetworkTarget',
        'platform_target': 'CampaignTargetServicePlatformTarget',
        'schedule_target': 'CampaignTargetServiceScheduleTarget',
        'target_id': 'str',
        'target_type': 'CampaignTargetServiceTargetType'
    }

    attribute_map = {
        'location_target': 'locationTarget',
        'network_target': 'networkTarget',
        'platform_target': 'platformTarget',
        'schedule_target': 'scheduleTarget',
        'target_id': 'targetId',
        'target_type': 'targetType'
    }

    def __init__(self, location_target=None, network_target=None, platform_target=None, schedule_target=None, target_id=None, target_type=None, local_vars_configuration=None):  # noqa: E501
        """CampaignTargetServiceTarget - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._location_target = None
        self._network_target = None
        self._platform_target = None
        self._schedule_target = None
        self._target_id = None
        self._target_type = None
        self.discriminator = None

        self.location_target = location_target
        self.network_target = network_target
        self.platform_target = platform_target
        self.schedule_target = schedule_target
        self.target_id = target_id
        self.target_type = target_type

    @property
    def location_target(self):
        """Gets the location_target of this CampaignTargetServiceTarget.  # noqa: E501


        :return: The location_target of this CampaignTargetServiceTarget.  # noqa: E501
        :rtype: CampaignTargetServiceLocationTarget
        """
        return self._location_target

    @location_target.setter
    def location_target(self, location_target):
        """Sets the location_target of this CampaignTargetServiceTarget.


        :param location_target: The location_target of this CampaignTargetServiceTarget.  # noqa: E501
        :type: CampaignTargetServiceLocationTarget
        """

        self._location_target = location_target

    @property
    def network_target(self):
        """Gets the network_target of this CampaignTargetServiceTarget.  # noqa: E501


        :return: The network_target of this CampaignTargetServiceTarget.  # noqa: E501
        :rtype: CampaignTargetServiceNetworkTarget
        """
        return self._network_target

    @network_target.setter
    def network_target(self, network_target):
        """Sets the network_target of this CampaignTargetServiceTarget.


        :param network_target: The network_target of this CampaignTargetServiceTarget.  # noqa: E501
        :type: CampaignTargetServiceNetworkTarget
        """

        self._network_target = network_target

    @property
    def platform_target(self):
        """Gets the platform_target of this CampaignTargetServiceTarget.  # noqa: E501


        :return: The platform_target of this CampaignTargetServiceTarget.  # noqa: E501
        :rtype: CampaignTargetServicePlatformTarget
        """
        return self._platform_target

    @platform_target.setter
    def platform_target(self, platform_target):
        """Sets the platform_target of this CampaignTargetServiceTarget.


        :param platform_target: The platform_target of this CampaignTargetServiceTarget.  # noqa: E501
        :type: CampaignTargetServicePlatformTarget
        """

        self._platform_target = platform_target

    @property
    def schedule_target(self):
        """Gets the schedule_target of this CampaignTargetServiceTarget.  # noqa: E501


        :return: The schedule_target of this CampaignTargetServiceTarget.  # noqa: E501
        :rtype: CampaignTargetServiceScheduleTarget
        """
        return self._schedule_target

    @schedule_target.setter
    def schedule_target(self, schedule_target):
        """Sets the schedule_target of this CampaignTargetServiceTarget.


        :param schedule_target: The schedule_target of this CampaignTargetServiceTarget.  # noqa: E501
        :type: CampaignTargetServiceScheduleTarget
        """

        self._schedule_target = schedule_target

    @property
    def target_id(self):
        """Gets the target_id of this CampaignTargetServiceTarget.  # noqa: E501

        <div lang=\"ja\">ターゲットIDです。<br> このフィールドは、ADD時は無視され、SETおよびREMOVE時は必須となります。<br> ※LocationCampaignTargetServiceTargetの場合、ADD時に必須となります。<br> ※PlatformCampaignTargetServiceTargetの場合、SET時に無視されます。</div> <div lang=\"en\">CampaignTargetServiceTarget ID.<br> This field will be ignored in ADD operation, and is required in ADD and REMOVE operation.<br> *For LocationCampaignTargetServiceTarget, this is required in ADD operation.<br> *For PlatformCampaignTargetServiceTarget, this will be ignored in SET operation.</div>   # noqa: E501

        :return: The target_id of this CampaignTargetServiceTarget.  # noqa: E501
        :rtype: str
        """
        return self._target_id

    @target_id.setter
    def target_id(self, target_id):
        """Sets the target_id of this CampaignTargetServiceTarget.

        <div lang=\"ja\">ターゲットIDです。<br> このフィールドは、ADD時は無視され、SETおよびREMOVE時は必須となります。<br> ※LocationCampaignTargetServiceTargetの場合、ADD時に必須となります。<br> ※PlatformCampaignTargetServiceTargetの場合、SET時に無視されます。</div> <div lang=\"en\">CampaignTargetServiceTarget ID.<br> This field will be ignored in ADD operation, and is required in ADD and REMOVE operation.<br> *For LocationCampaignTargetServiceTarget, this is required in ADD operation.<br> *For PlatformCampaignTargetServiceTarget, this will be ignored in SET operation.</div>   # noqa: E501

        :param target_id: The target_id of this CampaignTargetServiceTarget.  # noqa: E501
        :type: str
        """

        self._target_id = target_id

    @property
    def target_type(self):
        """Gets the target_type of this CampaignTargetServiceTarget.  # noqa: E501


        :return: The target_type of this CampaignTargetServiceTarget.  # noqa: E501
        :rtype: CampaignTargetServiceTargetType
        """
        return self._target_type

    @target_type.setter
    def target_type(self, target_type):
        """Sets the target_type of this CampaignTargetServiceTarget.


        :param target_type: The target_type of this CampaignTargetServiceTarget.  # noqa: E501
        :type: CampaignTargetServiceTargetType
        """

        self._target_type = target_type

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CampaignTargetServiceTarget):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, CampaignTargetServiceTarget):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Yahoo!広告 検索広告 API リファレンス / Yahoo! JAPAN Ads Search Ads API Reference

    <div lang=\"ja\">Yahoo!広告 検索広告 APIのWebサービスについて説明します。</div> <div lang=\"en\">Search Ads API Web Services supported in Yahoo! JAPAN Ads API.</div> <div><a target=\"_blank\" href=\"https://github.com/yahoojp-marketing/ads-search-api-documents/blob/master/design/v12/Route.yaml\">OpenAPI Specification</a></div> <div lang=\"ja\"><a target=\"_blank\" href=\"https://github.com/yahoojp-marketing/ads-search-api-documents/blob/master/bestpractice/ja\">Best Practice</a></div> <div lang=\"en\"><a target=\"_blank\" href=\"https://github.com/yahoojp-marketing/ads-search-api-documents/blob/master/bestpractice/en\">Best Practice</a></div>   # noqa: E501

    The version of the OpenAPI document: v12
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from yahoo_search_api_v12.configuration import Configuration


class PageFeedAssetServiceReviewSummary(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'account_id': 'int',
        'approved_count': 'int',
        'approved_with_review_count': 'int',
        'entity_count': 'int',
        'page_feed_asset_set_id': 'int',
        'post_disapproved_count': 'int',
        'pre_disapproved_count': 'int',
        'review_count': 'int'
    }

    attribute_map = {
        'account_id': 'accountId',
        'approved_count': 'approvedCount',
        'approved_with_review_count': 'approvedWithReviewCount',
        'entity_count': 'entityCount',
        'page_feed_asset_set_id': 'pageFeedAssetSetId',
        'post_disapproved_count': 'postDisapprovedCount',
        'pre_disapproved_count': 'preDisapprovedCount',
        'review_count': 'reviewCount'
    }

    def __init__(self, account_id=None, approved_count=None, approved_with_review_count=None, entity_count=None, page_feed_asset_set_id=None, post_disapproved_count=None, pre_disapproved_count=None, review_count=None, local_vars_configuration=None):  # noqa: E501
        """PageFeedAssetServiceReviewSummary - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._account_id = None
        self._approved_count = None
        self._approved_with_review_count = None
        self._entity_count = None
        self._page_feed_asset_set_id = None
        self._post_disapproved_count = None
        self._pre_disapproved_count = None
        self._review_count = None
        self.discriminator = None

        self.account_id = account_id
        self.approved_count = approved_count
        self.approved_with_review_count = approved_with_review_count
        self.entity_count = entity_count
        self.page_feed_asset_set_id = page_feed_asset_set_id
        self.post_disapproved_count = post_disapproved_count
        self.pre_disapproved_count = pre_disapproved_count
        self.review_count = review_count

    @property
    def account_id(self):
        """Gets the account_id of this PageFeedAssetServiceReviewSummary.  # noqa: E501

        <div lang=\"ja\">アカウントID</div> <div lang=\"en\">Account ID.</div>   # noqa: E501

        :return: The account_id of this PageFeedAssetServiceReviewSummary.  # noqa: E501
        :rtype: int
        """
        return self._account_id

    @account_id.setter
    def account_id(self, account_id):
        """Sets the account_id of this PageFeedAssetServiceReviewSummary.

        <div lang=\"ja\">アカウントID</div> <div lang=\"en\">Account ID.</div>   # noqa: E501

        :param account_id: The account_id of this PageFeedAssetServiceReviewSummary.  # noqa: E501
        :type: int
        """

        self._account_id = account_id

    @property
    def approved_count(self):
        """Gets the approved_count of this PageFeedAssetServiceReviewSummary.  # noqa: E501

        <div lang=\"ja\">承認済みの件数</div> <div lang=\"en\">Count of approved.</div>   # noqa: E501

        :return: The approved_count of this PageFeedAssetServiceReviewSummary.  # noqa: E501
        :rtype: int
        """
        return self._approved_count

    @approved_count.setter
    def approved_count(self, approved_count):
        """Sets the approved_count of this PageFeedAssetServiceReviewSummary.

        <div lang=\"ja\">承認済みの件数</div> <div lang=\"en\">Count of approved.</div>   # noqa: E501

        :param approved_count: The approved_count of this PageFeedAssetServiceReviewSummary.  # noqa: E501
        :type: int
        """

        self._approved_count = approved_count

    @property
    def approved_with_review_count(self):
        """Gets the approved_with_review_count of this PageFeedAssetServiceReviewSummary.  # noqa: E501

        <div lang=\"ja\">編集内容審査中の件数</div> <div lang=\"en\">Count of approved with review.</div>   # noqa: E501

        :return: The approved_with_review_count of this PageFeedAssetServiceReviewSummary.  # noqa: E501
        :rtype: int
        """
        return self._approved_with_review_count

    @approved_with_review_count.setter
    def approved_with_review_count(self, approved_with_review_count):
        """Sets the approved_with_review_count of this PageFeedAssetServiceReviewSummary.

        <div lang=\"ja\">編集内容審査中の件数</div> <div lang=\"en\">Count of approved with review.</div>   # noqa: E501

        :param approved_with_review_count: The approved_with_review_count of this PageFeedAssetServiceReviewSummary.  # noqa: E501
        :type: int
        """

        self._approved_with_review_count = approved_with_review_count

    @property
    def entity_count(self):
        """Gets the entity_count of this PageFeedAssetServiceReviewSummary.  # noqa: E501

        <div lang=\"ja\">ページフィードアセットセット内にあるページフィードアセットの総件数</div> <div lang=\"en\">Total count of page feed asset in page feed asset set.</div>   # noqa: E501

        :return: The entity_count of this PageFeedAssetServiceReviewSummary.  # noqa: E501
        :rtype: int
        """
        return self._entity_count

    @entity_count.setter
    def entity_count(self, entity_count):
        """Sets the entity_count of this PageFeedAssetServiceReviewSummary.

        <div lang=\"ja\">ページフィードアセットセット内にあるページフィードアセットの総件数</div> <div lang=\"en\">Total count of page feed asset in page feed asset set.</div>   # noqa: E501

        :param entity_count: The entity_count of this PageFeedAssetServiceReviewSummary.  # noqa: E501
        :type: int
        """

        self._entity_count = entity_count

    @property
    def page_feed_asset_set_id(self):
        """Gets the page_feed_asset_set_id of this PageFeedAssetServiceReviewSummary.  # noqa: E501

        <div lang=\"ja\">ページフィードアセットセットID</div> <div lang=\"en\">PageFeedAssetSet ID.</div>   # noqa: E501

        :return: The page_feed_asset_set_id of this PageFeedAssetServiceReviewSummary.  # noqa: E501
        :rtype: int
        """
        return self._page_feed_asset_set_id

    @page_feed_asset_set_id.setter
    def page_feed_asset_set_id(self, page_feed_asset_set_id):
        """Sets the page_feed_asset_set_id of this PageFeedAssetServiceReviewSummary.

        <div lang=\"ja\">ページフィードアセットセットID</div> <div lang=\"en\">PageFeedAssetSet ID.</div>   # noqa: E501

        :param page_feed_asset_set_id: The page_feed_asset_set_id of this PageFeedAssetServiceReviewSummary.  # noqa: E501
        :type: int
        """

        self._page_feed_asset_set_id = page_feed_asset_set_id

    @property
    def post_disapproved_count(self):
        """Gets the post_disapproved_count of this PageFeedAssetServiceReviewSummary.  # noqa: E501

        <div lang=\"ja\">配信停止の件数</div> <div lang=\"en\">Count of distribution cancelled.</div>   # noqa: E501

        :return: The post_disapproved_count of this PageFeedAssetServiceReviewSummary.  # noqa: E501
        :rtype: int
        """
        return self._post_disapproved_count

    @post_disapproved_count.setter
    def post_disapproved_count(self, post_disapproved_count):
        """Sets the post_disapproved_count of this PageFeedAssetServiceReviewSummary.

        <div lang=\"ja\">配信停止の件数</div> <div lang=\"en\">Count of distribution cancelled.</div>   # noqa: E501

        :param post_disapproved_count: The post_disapproved_count of this PageFeedAssetServiceReviewSummary.  # noqa: E501
        :type: int
        """

        self._post_disapproved_count = post_disapproved_count

    @property
    def pre_disapproved_count(self):
        """Gets the pre_disapproved_count of this PageFeedAssetServiceReviewSummary.  # noqa: E501

        <div lang=\"ja\">掲載不可の件数</div> <div lang=\"en\">Count of disapproved.</div>   # noqa: E501

        :return: The pre_disapproved_count of this PageFeedAssetServiceReviewSummary.  # noqa: E501
        :rtype: int
        """
        return self._pre_disapproved_count

    @pre_disapproved_count.setter
    def pre_disapproved_count(self, pre_disapproved_count):
        """Sets the pre_disapproved_count of this PageFeedAssetServiceReviewSummary.

        <div lang=\"ja\">掲載不可の件数</div> <div lang=\"en\">Count of disapproved.</div>   # noqa: E501

        :param pre_disapproved_count: The pre_disapproved_count of this PageFeedAssetServiceReviewSummary.  # noqa: E501
        :type: int
        """

        self._pre_disapproved_count = pre_disapproved_count

    @property
    def review_count(self):
        """Gets the review_count of this PageFeedAssetServiceReviewSummary.  # noqa: E501

        <div lang=\"ja\">審査中の件数</div> <div lang=\"en\">Count of review.</div>   # noqa: E501

        :return: The review_count of this PageFeedAssetServiceReviewSummary.  # noqa: E501
        :rtype: int
        """
        return self._review_count

    @review_count.setter
    def review_count(self, review_count):
        """Sets the review_count of this PageFeedAssetServiceReviewSummary.

        <div lang=\"ja\">審査中の件数</div> <div lang=\"en\">Count of review.</div>   # noqa: E501

        :param review_count: The review_count of this PageFeedAssetServiceReviewSummary.  # noqa: E501
        :type: int
        """

        self._review_count = review_count

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PageFeedAssetServiceReviewSummary):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, PageFeedAssetServiceReviewSummary):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Yahoo!広告 検索広告 API リファレンス / Yahoo! JAPAN Ads Search Ads API Reference

    <div lang=\"ja\">Yahoo!広告 検索広告 APIのWebサービスについて説明します。</div> <div lang=\"en\">Search Ads API Web Services supported in Yahoo! JAPAN Ads API.</div> <div><a target=\"_blank\" href=\"https://github.com/yahoojp-marketing/ads-search-api-documents/blob/master/design/v12/Route.yaml\">OpenAPI Specification</a></div> <div lang=\"ja\"><a target=\"_blank\" href=\"https://github.com/yahoojp-marketing/ads-search-api-documents/blob/master/bestpractice/ja\">Best Practice</a></div> <div lang=\"en\"><a target=\"_blank\" href=\"https://github.com/yahoojp-marketing/ads-search-api-documents/blob/master/bestpractice/en\">Best Practice</a></div>   # noqa: E501

    The version of the OpenAPI document: v12
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from yahoo_search_api_v12.configuration import Configuration


class KeywordForecastMetrics(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'keyword': 'str',
        'impressions': 'float',
        'ctr': 'float',
        'average_cpc': 'float',
        'clicks': 'float',
        'cost': 'float'
    }

    attribute_map = {
        'keyword': 'keyword',
        'impressions': 'impressions',
        'ctr': 'ctr',
        'average_cpc': 'averageCpc',
        'clicks': 'clicks',
        'cost': 'cost'
    }

    def __init__(self, keyword=None, impressions=None, ctr=None, average_cpc=None, clicks=None, cost=None, local_vars_configuration=None):  # noqa: E501
        """KeywordForecastMetrics - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._keyword = None
        self._impressions = None
        self._ctr = None
        self._average_cpc = None
        self._clicks = None
        self._cost = None
        self.discriminator = None

        self.keyword = keyword
        self.impressions = impressions
        self.ctr = ctr
        self.average_cpc = average_cpc
        self.clicks = clicks
        self.cost = cost

    @property
    def keyword(self):
        """Gets the keyword of this KeywordForecastMetrics.  # noqa: E501

        <div lang=\"ja\">キーワードです。</div> <div lang=\"en\">Keywords.</div>   # noqa: E501

        :return: The keyword of this KeywordForecastMetrics.  # noqa: E501
        :rtype: str
        """
        return self._keyword

    @keyword.setter
    def keyword(self, keyword):
        """Sets the keyword of this KeywordForecastMetrics.

        <div lang=\"ja\">キーワードです。</div> <div lang=\"en\">Keywords.</div>   # noqa: E501

        :param keyword: The keyword of this KeywordForecastMetrics.  # noqa: E501
        :type: str
        """

        self._keyword = keyword

    @property
    def impressions(self):
        """Gets the impressions of this KeywordForecastMetrics.  # noqa: E501

        <div lang=\"ja\">インプレッション数です。</div> <div lang=\"en\">Number of impression.</div>   # noqa: E501

        :return: The impressions of this KeywordForecastMetrics.  # noqa: E501
        :rtype: float
        """
        return self._impressions

    @impressions.setter
    def impressions(self, impressions):
        """Sets the impressions of this KeywordForecastMetrics.

        <div lang=\"ja\">インプレッション数です。</div> <div lang=\"en\">Number of impression.</div>   # noqa: E501

        :param impressions: The impressions of this KeywordForecastMetrics.  # noqa: E501
        :type: float
        """

        self._impressions = impressions

    @property
    def ctr(self):
        """Gets the ctr of this KeywordForecastMetrics.  # noqa: E501

        <div lang=\"ja\">クリック率です。</div> <div lang=\"en\">Click rate.</div>   # noqa: E501

        :return: The ctr of this KeywordForecastMetrics.  # noqa: E501
        :rtype: float
        """
        return self._ctr

    @ctr.setter
    def ctr(self, ctr):
        """Sets the ctr of this KeywordForecastMetrics.

        <div lang=\"ja\">クリック率です。</div> <div lang=\"en\">Click rate.</div>   # noqa: E501

        :param ctr: The ctr of this KeywordForecastMetrics.  # noqa: E501
        :type: float
        """

        self._ctr = ctr

    @property
    def average_cpc(self):
        """Gets the average_cpc of this KeywordForecastMetrics.  # noqa: E501

        <div lang=\"ja\">平均CPCです。</div> <div lang=\"en\">Average CPC.</div>   # noqa: E501

        :return: The average_cpc of this KeywordForecastMetrics.  # noqa: E501
        :rtype: float
        """
        return self._average_cpc

    @average_cpc.setter
    def average_cpc(self, average_cpc):
        """Sets the average_cpc of this KeywordForecastMetrics.

        <div lang=\"ja\">平均CPCです。</div> <div lang=\"en\">Average CPC.</div>   # noqa: E501

        :param average_cpc: The average_cpc of this KeywordForecastMetrics.  # noqa: E501
        :type: float
        """

        self._average_cpc = average_cpc

    @property
    def clicks(self):
        """Gets the clicks of this KeywordForecastMetrics.  # noqa: E501

        <div lang=\"ja\">クリック数です。</div> <div lang=\"en\">Number of click.</div>   # noqa: E501

        :return: The clicks of this KeywordForecastMetrics.  # noqa: E501
        :rtype: float
        """
        return self._clicks

    @clicks.setter
    def clicks(self, clicks):
        """Sets the clicks of this KeywordForecastMetrics.

        <div lang=\"ja\">クリック数です。</div> <div lang=\"en\">Number of click.</div>   # noqa: E501

        :param clicks: The clicks of this KeywordForecastMetrics.  # noqa: E501
        :type: float
        """

        self._clicks = clicks

    @property
    def cost(self):
        """Gets the cost of this KeywordForecastMetrics.  # noqa: E501

        <div lang=\"ja\">コストです。</div> <div lang=\"en\">Cost.</div>   # noqa: E501

        :return: The cost of this KeywordForecastMetrics.  # noqa: E501
        :rtype: float
        """
        return self._cost

    @cost.setter
    def cost(self, cost):
        """Sets the cost of this KeywordForecastMetrics.

        <div lang=\"ja\">コストです。</div> <div lang=\"en\">Cost.</div>   # noqa: E501

        :param cost: The cost of this KeywordForecastMetrics.  # noqa: E501
        :type: float
        """

        self._cost = cost

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, KeywordForecastMetrics):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, KeywordForecastMetrics):
            return True

        return self.to_dict() != other.to_dict()
